Method: Aws::Backup::Client#put_backup_vault_access_policy

Defined in:
lib/aws-sdk-backup/client.rb

#put_backup_vault_access_policy(params = {}) ⇒ Struct

Sets a resource-based policy that is used to manage access permissions on the target backup vault. Requires a backup vault name and an access policy document in JSON format.

Examples:

Request syntax with placeholder values


resp = client.put_backup_vault_access_policy({
  backup_vault_name: "BackupVaultName", # required
  policy: "IAMPolicy",
})

Options Hash (params):

  • :backup_vault_name (required, String)

    The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

  • :policy (String)

    The backup vault access policy document in JSON format.

See Also:

Parameters:

  • (defaults to: {})

    ({})

Returns:

  • Returns an empty response.



5883
5884
5885
5886
# File 'lib/aws-sdk-backup/client.rb', line 5883

def put_backup_vault_access_policy(params = {}, options = {})
  req = build_request(:put_backup_vault_access_policy, params)
  req.send_request(options)
end