Class: Aws::Backup::Types::BackupSelection
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::BackupSelection
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Used to specify a set of resources to a backup plan.
We recommend that you specify conditions, tags, or resources to include or exclude. Otherwise, Backup attempts to select all supported and opted-in storage resources, which could have unintended cost implications.
For more information, see [Assigning resources programmatically].
[1]: docs.aws.amazon.com/aws-backup/latest/devguide/assigning-resources.html#assigning-resources-json
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#conditions ⇒ Types::Conditions
The conditions that you define to assign resources to your backup plans using tags.
-
#iam_role_arn ⇒ String
The ARN of the IAM role that Backup uses to authenticate when backing up the target resource; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
-
#list_of_tags ⇒ Array<Types::Condition>
The conditions that you define to assign resources to your backup plans using tags.
-
#not_resources ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resources to exclude from a backup plan.
-
#resources ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resources to assign to a backup plan.
-
#selection_name ⇒ String
The display name of a resource selection document.
Instance Attribute Details
#conditions ⇒ Types::Conditions
The conditions that you define to assign resources to your backup plans using tags. For example, ‘“StringEquals”: { “ConditionKey”: “aws:ResourceTag/backup”, “ConditionValue”: “daily” }`.
‘Conditions` supports `StringEquals`, `StringLike`, `StringNotEquals`, and `StringNotLike`. Condition operators are case sensitive.
If you specify multiple conditions, the resources much match all conditions (AND logic).
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The ARN of the IAM role that Backup uses to authenticate when backing up the target resource; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |
#list_of_tags ⇒ Array<Types::Condition>
The conditions that you define to assign resources to your backup plans using tags. For example, ‘“StringEquals”: { “ConditionKey”: “backup”, “ConditionValue”: “daily”}`.
‘ListOfTags` supports only `StringEquals`. Condition operators are case sensitive.
If you specify multiple conditions, the resources much match any of the conditions (OR logic).
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |
#not_resources ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resources to exclude from a backup plan. The maximum number of ARNs is 500 without wildcards, or 30 ARNs with wildcards.
If you need to exclude many resources from a backup plan, consider a different resource selection strategy, such as assigning only one or a few resource types or refining your resource selection using tags.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |
#resources ⇒ Array<String>
The Amazon Resource Names (ARNs) of the resources to assign to a backup plan. The maximum number of ARNs is 500 without wildcards, or 30 ARNs with wildcards.
If you need to assign many resources to a backup plan, consider a different resource selection strategy, such as assigning all resources of a resource type or refining your resource selection using tags.
If you specify multiple ARNs, the resources much match any of the ARNs (OR logic).
<note markdown=“1”> When using wildcards in ARN patterns for backup selections, the asterisk (*) must appear at the end of the ARN string (prefix pattern). For example, ‘arn:aws:s3:::my-bucket-*` is valid, but `arn:aws:s3:::*-logs` is not supported.
</note>
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |
#selection_name ⇒ String
The display name of a resource selection document. Must contain 1 to 50 alphanumeric or ‘-_.’ characters.
1046 1047 1048 1049 1050 1051 1052 1053 1054 1055 |
# File 'lib/aws-sdk-backup/types.rb', line 1046 class BackupSelection < Struct.new( :selection_name, :iam_role_arn, :resources, :list_of_tags, :not_resources, :conditions) SENSITIVE = [] include Aws::Structure end |