Class: Aws::Backup::Types::BackupSelectionsListMember

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Contains metadata about a BackupSelection object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plan_idString

Uniquely identifies a backup plan.

Returns:

  • (String)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time a backup plan is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. This parameter is optional.

If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters.

Returns:

  • (String)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

Specifies the IAM role Amazon Resource Name (ARN) to create the target recovery point; for example, arn:aws:iam::123456789012:role/S3Access.

Returns:

  • (String)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#selection_idString

Uniquely identifies a request to assign a set of resources to a backup plan.

Returns:

  • (String)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#selection_nameString

The display name of a resource selection document.

Returns:

  • (String)


1096
1097
1098
1099
1100
1101
1102
1103
1104
1105
# File 'lib/aws-sdk-backup/types.rb', line 1096

class BackupSelectionsListMember < Struct.new(
  :selection_id,
  :selection_name,
  :backup_plan_id,
  :creation_date,
  :creator_request_id,
  :iam_role_arn)
  SENSITIVE = []
  include Aws::Structure
end