Class: Aws::Backup::Types::Condition
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::Condition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains an array of triplets made up of a condition type (such as StringEquals), a key, and a value. Used to filter resources using their tags and assign them to a backup plan. Case sensitive.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#condition_key ⇒ String
The key in a key-value pair.
-
#condition_type ⇒ String
An operation applied to a key-value pair used to assign resources to your backup plan.
-
#condition_value ⇒ String
The value in a key-value pair.
Instance Attribute Details
#condition_key ⇒ String
The key in a key-value pair. For example, in the tag ‘Department: Accounting`, Department is the key.
1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-backup/types.rb', line 1099 class Condition < Struct.new( :condition_type, :condition_key, :condition_value) SENSITIVE = [] include Aws::Structure end |
#condition_type ⇒ String
An operation applied to a key-value pair used to assign resources to your backup plan. Condition only supports StringEquals. For more flexible assignment options, including StringLike and the ability to exclude resources from your backup plan, use Conditions (with an “s” on the end) for your [ BackupSelection ][1].
[1]: docs.aws.amazon.com/aws-backup/latest/devguide/API_BackupSelection.html
1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-backup/types.rb', line 1099 class Condition < Struct.new( :condition_type, :condition_key, :condition_value) SENSITIVE = [] include Aws::Structure end |
#condition_value ⇒ String
The value in a key-value pair. For example, in the tag ‘Department: Accounting`, Accounting is the value.
1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/aws-sdk-backup/types.rb', line 1099 class Condition < Struct.new( :condition_type, :condition_key, :condition_value) SENSITIVE = [] include Aws::Structure end |