Class: Aws::Backup::Types::Conditions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::Conditions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains information about which resources to include or exclude from a backup plan using their tags. Conditions are case sensitive.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#string_equals ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for only those resources that you tagged with the same value.
-
#string_like ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for matching tag values with the use of a wildcard character (*) anywhere in the string.
-
#string_not_equals ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for only those resources that you tagged that do not have the same value.
-
#string_not_like ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for non-matching tag values with the use of a wildcard character (*) anywhere in the string.
Instance Attribute Details
#string_equals ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for only those resources that you tagged with the same value. Also called "exact matching."
1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-backup/types.rb', line 1400 class Conditions < Struct.new( :string_equals, :string_not_equals, :string_like, :string_not_like) SENSITIVE = [] include Aws::Structure end |
#string_like ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for matching tag values with the use of a wildcard character () anywhere in the string. For example, "prod" or "rod" matches the tag value "production".
1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-backup/types.rb', line 1400 class Conditions < Struct.new( :string_equals, :string_not_equals, :string_like, :string_not_like) SENSITIVE = [] include Aws::Structure end |
#string_not_equals ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for only those resources that you tagged that do not have the same value. Also called "negated matching."
1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-backup/types.rb', line 1400 class Conditions < Struct.new( :string_equals, :string_not_equals, :string_like, :string_not_like) SENSITIVE = [] include Aws::Structure end |
#string_not_like ⇒ Array<Types::ConditionParameter>
Filters the values of your tagged resources for non-matching tag values with the use of a wildcard character (*) anywhere in the string.
1400 1401 1402 1403 1404 1405 1406 1407 |
# File 'lib/aws-sdk-backup/types.rb', line 1400 class Conditions < Struct.new( :string_equals, :string_not_equals, :string_like, :string_not_like) SENSITIVE = [] include Aws::Structure end |