Class: Aws::Backup::Types::CreateBackupAccessPointResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The Amazon Resource Name (ARN) that uniquely identifies the created backup access point.

Returns:

  • (String)


1909
1910
1911
1912
1913
1914
# File 'lib/aws-sdk-backup/types.rb', line 1909

class CreateBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the backup access point. A newly created backup access point begins in the CREATING state and becomes usable when it reaches AVAILABLE.

Returns:

  • (String)


1909
1910
1911
1912
1913
1914
# File 'lib/aws-sdk-backup/types.rb', line 1909

class CreateBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :status)
  SENSITIVE = []
  include Aws::Structure
end