Class: Aws::Backup::Types::CreateBackupPlanOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#advanced_backup_settingsArray<Types::AdvancedBackupSetting>

The settings for a resource type. This option is only available for Windows Volume Shadow Copy Service (VSS) backup jobs.

Returns:



1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/aws-sdk-backup/types.rb', line 1977

class CreateBackupPlanOutput < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :creation_date,
  :version_id,
  :advanced_backup_settings)
  SENSITIVE = []
  include Aws::Structure
end

#backup_plan_arnString

An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50.

Returns:

  • (String)


1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/aws-sdk-backup/types.rb', line 1977

class CreateBackupPlanOutput < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :creation_date,
  :version_id,
  :advanced_backup_settings)
  SENSITIVE = []
  include Aws::Structure
end

#backup_plan_idString

The ID of the backup plan.

Returns:

  • (String)


1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/aws-sdk-backup/types.rb', line 1977

class CreateBackupPlanOutput < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :creation_date,
  :version_id,
  :advanced_backup_settings)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time that a backup plan is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/aws-sdk-backup/types.rb', line 1977

class CreateBackupPlanOutput < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :creation_date,
  :version_id,
  :advanced_backup_settings)
  SENSITIVE = []
  include Aws::Structure
end

#version_idString

Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. They cannot be edited.

Returns:

  • (String)


1977
1978
1979
1980
1981
1982
1983
1984
1985
# File 'lib/aws-sdk-backup/types.rb', line 1977

class CreateBackupPlanOutput < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :creation_date,
  :version_id,
  :advanced_backup_settings)
  SENSITIVE = []
  include Aws::Structure
end