Class: Aws::Backup::Types::CreateBackupSelectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plan_idString

The ID of the backup plan.

Returns:

  • (String)


2009
2010
2011
2012
2013
2014
2015
# File 'lib/aws-sdk-backup/types.rb', line 2009

class CreateBackupSelectionInput < Struct.new(
  :backup_plan_id,
  :backup_selection,
  :creator_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#backup_selectionTypes::BackupSelection

The body of a request to assign a set of resources to a backup plan.



2009
2010
2011
2012
2013
2014
2015
# File 'lib/aws-sdk-backup/types.rb', line 2009

class CreateBackupSelectionInput < Struct.new(
  :backup_plan_id,
  :backup_selection,
  :creator_request_id)
  SENSITIVE = []
  include Aws::Structure
end

#creator_request_idString

A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. This parameter is optional.

If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2009
2010
2011
2012
2013
2014
2015
# File 'lib/aws-sdk-backup/types.rb', line 2009

class CreateBackupSelectionInput < Struct.new(
  :backup_plan_id,
  :backup_selection,
  :creator_request_id)
  SENSITIVE = []
  include Aws::Structure
end