Class: Aws::Backup::Types::CreateBackupSelectionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plan_idString

The ID of the backup plan.

Returns:

  • (String)


2035
2036
2037
2038
2039
2040
2041
# File 'lib/aws-sdk-backup/types.rb', line 2035

class CreateBackupSelectionOutput < Struct.new(
  :selection_id,
  :backup_plan_id,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The date and time a backup selection is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


2035
2036
2037
2038
2039
2040
2041
# File 'lib/aws-sdk-backup/types.rb', line 2035

class CreateBackupSelectionOutput < Struct.new(
  :selection_id,
  :backup_plan_id,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end

#selection_idString

Uniquely identifies the body of a request to assign a set of resources to a backup plan.

Returns:

  • (String)


2035
2036
2037
2038
2039
2040
2041
# File 'lib/aws-sdk-backup/types.rb', line 2035

class CreateBackupSelectionOutput < Struct.new(
  :selection_id,
  :backup_plan_id,
  :creation_date)
  SENSITIVE = []
  include Aws::Structure
end