Class: Aws::Backup::Types::CreateBackupVaultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::CreateBackupVaultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:backup_vault_tags]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#backup_vault_tags ⇒ Hash<String,String>
The tags to assign to the backup vault.
-
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice.
-
#encryption_key_arn ⇒ String
The server-side encryption key that is used to protect your backups; for example,
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created. They consist of letters, numbers, and hyphens.
2074 2075 2076 2077 2078 2079 2080 2081 |
# File 'lib/aws-sdk-backup/types.rb', line 2074 class CreateBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_tags, :encryption_key_arn, :creator_request_id) SENSITIVE = [:backup_vault_tags] include Aws::Structure end |
#backup_vault_tags ⇒ Hash<String,String>
The tags to assign to the backup vault.
2074 2075 2076 2077 2078 2079 2080 2081 |
# File 'lib/aws-sdk-backup/types.rb', line 2074 class CreateBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_tags, :encryption_key_arn, :creator_request_id) SENSITIVE = [:backup_vault_tags] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. This parameter is optional.
If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters.
A suitable default value is auto-generated. You should normally not need to pass this option.
2074 2075 2076 2077 2078 2079 2080 2081 |
# File 'lib/aws-sdk-backup/types.rb', line 2074 class CreateBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_tags, :encryption_key_arn, :creator_request_id) SENSITIVE = [:backup_vault_tags] include Aws::Structure end |
#encryption_key_arn ⇒ String
The server-side encryption key that is used to protect your backups;
for example,
arn:aws:kms:us-west-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab.
2074 2075 2076 2077 2078 2079 2080 2081 |
# File 'lib/aws-sdk-backup/types.rb', line 2074 class CreateBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_tags, :encryption_key_arn, :creator_request_id) SENSITIVE = [:backup_vault_tags] include Aws::Structure end |