Class: Aws::Backup::Types::CreateRestoreTestingSelectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::CreateRestoreTestingSelectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creator_request_id ⇒ String
This is an optional unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice.
-
#restore_testing_plan_name ⇒ String
Input the restore testing plan name that was returned from the related CreateRestoreTestingPlan request.
-
#restore_testing_selection ⇒ Types::RestoreTestingSelectionForCreate
This consists of
RestoreTestingSelectionName,ProtectedResourceType, and one of the following:.
Instance Attribute Details
#creator_request_id ⇒ String
This is an optional unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters.
2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-backup/types.rb', line 2588 class CreateRestoreTestingSelectionInput < Struct.new( :creator_request_id, :restore_testing_plan_name, :restore_testing_selection) SENSITIVE = [] include Aws::Structure end |
#restore_testing_plan_name ⇒ String
Input the restore testing plan name that was returned from the related CreateRestoreTestingPlan request.
2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-backup/types.rb', line 2588 class CreateRestoreTestingSelectionInput < Struct.new( :creator_request_id, :restore_testing_plan_name, :restore_testing_selection) SENSITIVE = [] include Aws::Structure end |
#restore_testing_selection ⇒ Types::RestoreTestingSelectionForCreate
This consists of RestoreTestingSelectionName,
ProtectedResourceType, and one of the following:
-
ProtectedResourceArns -
ProtectedResourceConditions
Each protected resource type can have one single value.
A restore testing selection can include a wildcard value ("*")
for ProtectedResourceArns along with
ProtectedResourceConditions. Alternatively, you can include up to
30 specific protected resource ARNs in ProtectedResourceArns.
2588 2589 2590 2591 2592 2593 2594 |
# File 'lib/aws-sdk-backup/types.rb', line 2588 class CreateRestoreTestingSelectionInput < Struct.new( :creator_request_id, :restore_testing_plan_name, :restore_testing_selection) SENSITIVE = [] include Aws::Structure end |