Class: Aws::Backup::Types::CreateRestoreTestingSelectionOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The time that the resource testing selection was created.

Returns:

  • (Time)


2622
2623
2624
2625
2626
2627
2628
2629
# File 'lib/aws-sdk-backup/types.rb', line 2622

class CreateRestoreTestingSelectionOutput < Struct.new(
  :creation_time,
  :restore_testing_plan_arn,
  :restore_testing_plan_name,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end

#restore_testing_plan_arnString

The ARN of the restore testing plan with which the restore testing selection is associated.

Returns:

  • (String)


2622
2623
2624
2625
2626
2627
2628
2629
# File 'lib/aws-sdk-backup/types.rb', line 2622

class CreateRestoreTestingSelectionOutput < Struct.new(
  :creation_time,
  :restore_testing_plan_arn,
  :restore_testing_plan_name,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end

#restore_testing_plan_nameString

The name of the restore testing plan.

The name cannot be changed after creation. The name consists of only alphanumeric characters and underscores. Maximum length is 50.

Returns:

  • (String)


2622
2623
2624
2625
2626
2627
2628
2629
# File 'lib/aws-sdk-backup/types.rb', line 2622

class CreateRestoreTestingSelectionOutput < Struct.new(
  :creation_time,
  :restore_testing_plan_arn,
  :restore_testing_plan_name,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end

#restore_testing_selection_nameString

The name of the restore testing selection for the related restore testing plan.

The name cannot be changed after creation. The name consists of only alphanumeric characters and underscores. Maximum length is 50.

Returns:

  • (String)


2622
2623
2624
2625
2626
2627
2628
2629
# File 'lib/aws-sdk-backup/types.rb', line 2622

class CreateRestoreTestingSelectionOutput < Struct.new(
  :creation_time,
  :restore_testing_plan_arn,
  :restore_testing_plan_name,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end