Class: Aws::Backup::Types::DateRange
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DateRange
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
This is a resource filter containing FromDate: DateTime and ToDate: DateTime. Both values are required. Future DateTime values are not permitted.
The date and time are in Unix format and Coordinated Universal Time (UTC), and it is accurate to milliseconds ((milliseconds are optional). For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#from_date ⇒ Time
This value is the beginning date, inclusive.
-
#to_date ⇒ Time
This value is the end date, inclusive.
Instance Attribute Details
#from_date ⇒ Time
This value is the beginning date, inclusive.
The date and time are in Unix format and Coordinated Universal Time (UTC), and it is accurate to milliseconds (milliseconds are optional).
2722 2723 2724 2725 2726 2727 |
# File 'lib/aws-sdk-backup/types.rb', line 2722 class DateRange < Struct.new( :from_date, :to_date) SENSITIVE = [] include Aws::Structure end |
#to_date ⇒ Time
This value is the end date, inclusive.
The date and time are in Unix format and Coordinated Universal Time (UTC), and it is accurate to milliseconds (milliseconds are optional).
2722 2723 2724 2725 2726 2727 |
# File 'lib/aws-sdk-backup/types.rb', line 2722 class DateRange < Struct.new( :from_date, :to_date) SENSITIVE = [] include Aws::Structure end |