Class: Aws::Backup::Types::DeleteBackupPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DeleteBackupPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example,
arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50. -
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
-
#deletion_date ⇒ Time
The date and time a backup plan is deleted, in Unix format and Coordinated Universal Time (UTC).
-
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long.
Instance Attribute Details
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50.
2235 2236 2237 2238 2239 2240 2241 2242 |
# File 'lib/aws-sdk-backup/types.rb', line 2235 class DeleteBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :deletion_date, :version_id) SENSITIVE = [] include Aws::Structure end |
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
2235 2236 2237 2238 2239 2240 2241 2242 |
# File 'lib/aws-sdk-backup/types.rb', line 2235 class DeleteBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :deletion_date, :version_id) SENSITIVE = [] include Aws::Structure end |
#deletion_date ⇒ Time
The date and time a backup plan is deleted, in Unix format and Coordinated Universal Time (UTC). The value of DeletionDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
2235 2236 2237 2238 2239 2240 2241 2242 |
# File 'lib/aws-sdk-backup/types.rb', line 2235 class DeleteBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :deletion_date, :version_id) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version IDs cannot be edited.
2235 2236 2237 2238 2239 2240 2241 2242 |
# File 'lib/aws-sdk-backup/types.rb', line 2235 class DeleteBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :deletion_date, :version_id) SENSITIVE = [] include Aws::Structure end |