Class: Aws::Backup::Types::DeleteBackupVaultNotificationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.



2312
2313
2314
2315
2316
# File 'lib/aws-sdk-backup/types.rb', line 2312

class DeleteBackupVaultNotificationsInput < Struct.new(
  :backup_vault_name)
  SENSITIVE = []
  include Aws::Structure
end