Class: Aws::Backup::Types::DeleteRecoveryPointInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DeleteRecoveryPointInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-backup/types.rb', line 2887 class DeleteRecoveryPointInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery
point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
2887 2888 2889 2890 2891 2892 |
# File 'lib/aws-sdk-backup/types.rb', line 2887 class DeleteRecoveryPointInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |