Class: Aws::Backup::Types::DescribeBackupAccessPointResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:access_point_metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#access_point_arnString

The Amazon Resource Name (ARN) that uniquely identifies the backup access point.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#access_point_metadataHash<String,String>

Metadata for the backup access point. After the backup access point reaches the AVAILABLE status, this map contains S3AccessPointArn and S3AccessPointAlias, which you use with standard Amazon S3 read APIs to access the backup data. For continuous recovery points, this map also contains AccessPointInTime (in format 2021-11-27T03:30:27Z). The access point provides access to the content present in the backup at that specific time.

Returns:

  • (Hash<String,String>)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#backup_vault_arnString

The Amazon Resource Name (ARN) of the backup vault that contains the recovery point.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#backup_vault_nameString

The name of the backup vault that contains the recovery point.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#creation_timeTime

The date and time that the backup access point was created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#nameString

The name of the backup access point.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#recovery_point_arnString

The Amazon Resource Name (ARN) of the recovery point that the backup access point provides access to.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the resource that was backed up, such as an Amazon S3 bucket.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#resource_typeString

The type of Amazon Web Services resource associated with the recovery point. For example, S3 for Amazon Simple Storage Service.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#statusString

The current status of the backup access point.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end

#status_messageString

A message that provides additional detail about the status of the backup access point, such as the reason a creation or deletion attempt failed.

Returns:

  • (String)


3054
3055
3056
3057
3058
3059
3060
3061
3062
3063
3064
3065
3066
3067
3068
# File 'lib/aws-sdk-backup/types.rb', line 3054

class DescribeBackupAccessPointResponse < Struct.new(
  :access_point_arn,
  :access_point_metadata,
  :backup_vault_arn,
  :backup_vault_name,
  :creation_time,
  :name,
  :recovery_point_arn,
  :resource_arn,
  :resource_type,
  :status,
  :status_message)
  SENSITIVE = [:access_point_metadata]
  include Aws::Structure
end