Class: Aws::Backup::Types::DescribeBackupVaultInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_account_idString

The account ID of the specified backup vault.

Returns:

  • (String)


3370
3371
3372
3373
3374
3375
# File 'lib/aws-sdk-backup/types.rb', line 3370

class DescribeBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Returns:

  • (String)


3370
3371
3372
3373
3374
3375
# File 'lib/aws-sdk-backup/types.rb', line 3370

class DescribeBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id)
  SENSITIVE = []
  include Aws::Structure
end