Class: Aws::Backup::Types::DescribeReportPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeReportPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#report_plan ⇒ Types::ReportPlan
Returns details about the report plan that is specified by its name.
Instance Attribute Details
#report_plan ⇒ Types::ReportPlan
Returns details about the report plan that is specified by its name. These details include the report plan's Amazon Resource Name (ARN), description, settings, delivery channel, deployment status, creation time, and last attempted and successful run times.
4134 4135 4136 4137 4138 |
# File 'lib/aws-sdk-backup/types.rb', line 4134 class DescribeReportPlanOutput < Struct.new( :report_plan) SENSITIVE = [] include Aws::Structure end |