Class: Aws::Backup::Types::DescribeRestoreJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeRestoreJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Returns the account ID that owns the restore job.
-
#backup_size_in_bytes ⇒ Integer
The size, in bytes, of the restored resource.
-
#backup_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the backup vault containing the recovery point being restored.
-
#completion_date ⇒ Time
The date and time that a job to restore a recovery point is completed, in Unix format and Coordinated Universal Time (UTC).
-
#created_by ⇒ Types::RestoreJobCreator
Contains identifying information about the creation of a restore job.
-
#created_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that was created by the restore job.
-
#creation_date ⇒ Time
The date and time that a restore job is created, in Unix format and Coordinated Universal Time (UTC).
-
#deletion_status ⇒ String
The status of the data generated by the restore test.
-
#deletion_status_message ⇒ String
This describes the restore job deletion status.
-
#expected_completion_time_minutes ⇒ Integer
The amount of time in minutes that a job restoring a recovery point is expected to take.
-
#iam_role_arn ⇒ String
Specifies the IAM role ARN used to create the target recovery point; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
-
#is_parent ⇒ Boolean
This is a boolean value indicating whether the restore job is a parent (composite) restore job.
-
#parent_job_id ⇒ String
This is the unique identifier of the parent restore job for the selected restore job.
-
#percent_done ⇒ String
Contains an estimated percentage that is complete of a job at the time the job status was queried.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
-
#recovery_point_creation_date ⇒ Time
The creation date of the recovery point made by the specifed restore job.
-
#resource_type ⇒ String
Returns metadata associated with a restore job listed by resource type.
-
#restore_job_id ⇒ String
Uniquely identifies the job that restores a recovery point.
-
#source_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the original resource that was backed up.
-
#status ⇒ String
Status code specifying the state of the job that is initiated by Backup to restore a recovery point.
-
#status_message ⇒ String
A message showing the status of a job to restore a recovery point.
-
#validation_status ⇒ String
The status of validation run on the indicated restore job.
-
#validation_status_message ⇒ String
The status message.
Instance Attribute Details
#account_id ⇒ String
Returns the account ID that owns the restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#backup_size_in_bytes ⇒ Integer
The size, in bytes, of the restored resource.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#backup_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the backup vault containing the recovery point being restored. This helps identify vault access policies and permissions.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#completion_date ⇒ Time
The date and time that a job to restore a recovery point is completed, in Unix format and Coordinated Universal Time (UTC). The value of ‘CompletionDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::RestoreJobCreator
Contains identifying information about the creation of a restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#created_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that was created by the restore job.
The format of the ARN depends on the resource type of the backed-up resource.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a restore job is created, in Unix format and Coordinated Universal Time (UTC). The value of ‘CreationDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#deletion_status ⇒ String
The status of the data generated by the restore test.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#deletion_status_message ⇒ String
This describes the restore job deletion status.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#expected_completion_time_minutes ⇒ Integer
The amount of time in minutes that a job restoring a recovery point is expected to take.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
Specifies the IAM role ARN used to create the target recovery point; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#is_parent ⇒ Boolean
This is a boolean value indicating whether the restore job is a parent (composite) restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#parent_job_id ⇒ String
This is the unique identifier of the parent restore job for the selected restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#percent_done ⇒ String
Contains an estimated percentage that is complete of a job at the time the job status was queried.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#recovery_point_creation_date ⇒ Time
The creation date of the recovery point made by the specifed restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Returns metadata associated with a restore job listed by resource type.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#restore_job_id ⇒ String
Uniquely identifies the job that restores a recovery point.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#source_resource_arn ⇒ String
The Amazon Resource Name (ARN) of the original resource that was backed up. This provides context about what resource is being restored.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
Status code specifying the state of the job that is initiated by Backup to restore a recovery point.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A message showing the status of a job to restore a recovery point.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#validation_status ⇒ String
The status of validation run on the indicated restore job.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |
#validation_status_message ⇒ String
The status message.
4087 4088 4089 4090 4091 4092 4093 4094 4095 4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 |
# File 'lib/aws-sdk-backup/types.rb', line 4087 class DescribeRestoreJobOutput < Struct.new( :account_id, :restore_job_id, :recovery_point_arn, :source_resource_arn, :backup_vault_arn, :creation_date, :completion_date, :status, :status_message, :percent_done, :backup_size_in_bytes, :iam_role_arn, :expected_completion_time_minutes, :created_resource_arn, :resource_type, :recovery_point_creation_date, :created_by, :validation_status, :validation_status_message, :deletion_status, :deletion_status_message, :is_parent, :parent_job_id) SENSITIVE = [] include Aws::Structure end |