Class: Aws::Backup::Types::DescribeScanJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeScanJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Returns the account ID that owns the scan job.
-
#backup_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup vault; for example,
arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault. -
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#completion_date ⇒ Time
The date and time that a backup index finished creation, in Unix format and Coordinated Universal Time (UTC).
-
#continuous_scan_end_time ⇒ Time
The point in time the scan job scanned up to for a continuous backup.
-
#continuous_scan_start_time ⇒ Time
The point in time the scan job started scan from for a continuous backup.
-
#created_by ⇒ Types::ScanJobCreator
Contains identifying information about the creation of a scan job, including the backup plan and rule that initiated the scan.
-
#creation_date ⇒ Time
The date and time that a backup index finished creation, in Unix format and Coordinated Universal Time (UTC).
-
#iam_role_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup vault; for example,
arn:aws:iam::123456789012:role/S3Access. -
#malware_scanner ⇒ String
The scanning engine used for the corresponding scan job.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies the target recovery point for scanning.; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45. -
#resource_arn ⇒ String
An ARN that uniquely identifies the source resource of the corresponding recovery point ARN.
-
#resource_name ⇒ String
The non-unique name of the resource that belongs to the specified backup.
-
#resource_type ⇒ String
The type of Amazon Web Services Resource to be backed up; for example, an Amazon Elastic Block Store (Amazon EBS) volume.
-
#scan_base_recovery_point_arn ⇒ String
An ARN that uniquely identifies the base recovery point for scanning.
-
#scan_id ⇒ String
The scan ID generated by Amazon GuardDuty for the corresponding Scan Job ID request from Backup.
-
#scan_job_id ⇒ String
The scan job ID that uniquely identified the request to Backup.
-
#scan_mode ⇒ String
Specifies the scan type used for the scan job.
-
#scan_result ⇒ Types::ScanResultInfo
Contains the
ScanResultsStatusfor the scanning job and returnsTHREATS_FOUNDorNO_THREATS_FOUNDfor completed jobs. -
#scanner_role_arn ⇒ String
Specifies the scanner IAM role ARN used to for the scan job.
-
#state ⇒ String
The current state of a scan job.
-
#status_message ⇒ String
A detailed message explaining the status of the job to back up a resource.
Instance Attribute Details
#account_id ⇒ String
Returns the account ID that owns the scan job.
Pattern: ^[0-9]{12}$
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#backup_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup
vault; for example,
arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
Pattern: ^[a-zA-Z0-9\-\_\.]{2,50}$
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#completion_date ⇒ Time
The date and time that a backup index finished creation, in Unix
format and Coordinated Universal Time (UTC). The value of
CompletionDate is accurate to milliseconds. For example, the value
1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#continuous_scan_end_time ⇒ Time
The point in time the scan job scanned up to for a continuous backup.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#continuous_scan_start_time ⇒ Time
The point in time the scan job started scan from for a continuous backup.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::ScanJobCreator
Contains identifying information about the creation of a scan job, including the backup plan and rule that initiated the scan.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a backup index finished creation, in Unix
format and Coordinated Universal Time (UTC). The value of
CreationDate is accurate to milliseconds. For example, the value
1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup
vault; for example, arn:aws:iam::123456789012:role/S3Access.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#malware_scanner ⇒ String
The scanning engine used for the corresponding scan job. Currently
only GUARDUTY is supported.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies the target recovery point for
scanning.; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
An ARN that uniquely identifies the source resource of the corresponding recovery point ARN.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The non-unique name of the resource that belongs to the specified backup.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of Amazon Web Services Resource to be backed up; for example, an Amazon Elastic Block Store (Amazon EBS) volume.
Pattern: ^[a-zA-Z0-9\-\_\.]{1,50}$
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_base_recovery_point_arn ⇒ String
An ARN that uniquely identifies the base recovery point for scanning. This field will only be populated when an incremental scan job has taken place.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The scan ID generated by Amazon GuardDuty for the corresponding Scan Job ID request from Backup.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_job_id ⇒ String
The scan job ID that uniquely identified the request to Backup.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_mode ⇒ String
Specifies the scan type used for the scan job.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_result ⇒ Types::ScanResultInfo
Contains the ScanResultsStatus for the scanning job and returns
THREATS_FOUND or NO_THREATS_FOUND for completed jobs.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scanner_role_arn ⇒ String
Specifies the scanner IAM role ARN used to for the scan job.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of a scan job.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A detailed message explaining the status of the job to back up a resource.
4433 4434 4435 4436 4437 4438 4439 4440 4441 4442 4443 4444 4445 4446 4447 4448 4449 4450 4451 4452 4453 4454 4455 4456 4457 4458 |
# File 'lib/aws-sdk-backup/types.rb', line 4433 class DescribeScanJobOutput < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |