Class: Aws::Backup::Types::DisassociateRecoveryPointFromParentInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where the child (nested) recovery point is stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Returns:

  • (String)


4494
4495
4496
4497
4498
4499
# File 'lib/aws-sdk-backup/types.rb', line 4494

class DisassociateRecoveryPointFromParentInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

The Amazon Resource Name (ARN) that uniquely identifies the child (nested) recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

Returns:

  • (String)


4494
4495
4496
4497
4498
4499
# File 'lib/aws-sdk-backup/types.rb', line 4494

class DisassociateRecoveryPointFromParentInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end