Class: Aws::Backup::Types::GetBackupPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetBackupPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
Contains a list of ‘BackupOptions` for each resource type.
-
#backup_plan ⇒ Types::BackupPlan
Specifies the body of a backup plan.
-
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, ‘arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50`.
-
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
-
#creation_date ⇒ Time
The date and time that a backup plan is created, in Unix format and Coordinated Universal Time (UTC).
-
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice.
-
#deletion_date ⇒ Time
The date and time that a backup plan is deleted, in Unix format and Coordinated Universal Time (UTC).
-
#last_execution_date ⇒ Time
The last time this backup plan was run.
-
#scheduled_runs_preview ⇒ Array<Types::ScheduledPlanExecutionMember>
List of upcoming scheduled backup runs.
-
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long.
Instance Attribute Details
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
Contains a list of ‘BackupOptions` for each resource type. The list is populated only if the advanced option is set for the backup plan.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#backup_plan ⇒ Types::BackupPlan
Specifies the body of a backup plan. Includes a ‘BackupPlanName` and one or more sets of `Rules`.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, ‘arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50`.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a backup plan is created, in Unix format and Coordinated Universal Time (UTC). The value of ‘CreationDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#deletion_date ⇒ Time
The date and time that a backup plan is deleted, in Unix format and Coordinated Universal Time (UTC). The value of ‘DeletionDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#last_execution_date ⇒ Time
The last time this backup plan was run. A date and time, in Unix format and Coordinated Universal Time (UTC). The value of ‘LastExecutionDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#scheduled_runs_preview ⇒ Array<Types::ScheduledPlanExecutionMember>
List of upcoming scheduled backup runs. Only included when ‘MaxScheduledRunsPreview` parameter is greater than 0. Contains up to 10 future backup executions with their scheduled times, execution types, and associated rule IDs.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version IDs cannot be edited.
4574 4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 |
# File 'lib/aws-sdk-backup/types.rb', line 4574 class GetBackupPlanOutput < Struct.new( :backup_plan, :backup_plan_id, :backup_plan_arn, :version_id, :creator_request_id, :creation_date, :deletion_date, :last_execution_date, :advanced_backup_settings, :scheduled_runs_preview) SENSITIVE = [] include Aws::Structure end |