Method: Aws::Backup::Types::GetBackupVaultAccessPolicyOutput#backup_vault_name

Defined in:
lib/aws-sdk-backup/types.rb

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.

Returns:

  • (String)


4655
4656
4657
4658
4659
4660
4661
# File 'lib/aws-sdk-backup/types.rb', line 4655

class GetBackupVaultAccessPolicyOutput < Struct.new(
  :backup_vault_name,
  :backup_vault_arn,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end