Class: Aws::Backup::Types::GetBackupVaultNotificationsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Returns:

  • (String)


4892
4893
4894
4895
4896
# File 'lib/aws-sdk-backup/types.rb', line 4892

class GetBackupVaultNotificationsInput < Struct.new(
  :backup_vault_name)
  SENSITIVE = []
  include Aws::Structure
end