Class: Aws::Backup::Types::GetBackupVaultNotificationsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_arnString

An Amazon Resource Name (ARN) that uniquely identifies a backup vault; for example, arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault.



3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-backup/types.rb', line 3871

class GetBackupVaultNotificationsOutput < Struct.new(
  :backup_vault_name,
  :backup_vault_arn,
  :sns_topic_arn,
  :backup_vault_events)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vault_eventsArray<String>

An array of events that indicate the status of jobs to back up resources to the backup vault.



3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-backup/types.rb', line 3871

class GetBackupVaultNotificationsOutput < Struct.new(
  :backup_vault_name,
  :backup_vault_arn,
  :sns_topic_arn,
  :backup_vault_events)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.



3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-backup/types.rb', line 3871

class GetBackupVaultNotificationsOutput < Struct.new(
  :backup_vault_name,
  :backup_vault_arn,
  :sns_topic_arn,
  :backup_vault_events)
  SENSITIVE = []
  include Aws::Structure
end

#sns_topic_arnString

An ARN that uniquely identifies an Amazon Simple Notification Service (Amazon SNS) topic; for example, arn:aws:sns:us-west-2:111122223333:MyTopic.



3871
3872
3873
3874
3875
3876
3877
3878
# File 'lib/aws-sdk-backup/types.rb', line 3871

class GetBackupVaultNotificationsOutput < Struct.new(
  :backup_vault_name,
  :backup_vault_arn,
  :sns_topic_arn,
  :backup_vault_events)
  SENSITIVE = []
  include Aws::Structure
end