Class: Aws::Backup::Types::GetLegalHoldOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#cancel_descriptionString

The reason for removing the legal hold.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#cancellation_dateTime

The time when the legal hold was cancelled.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#creation_dateTime

The time when the legal hold was created.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the legal hold.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

The framework ARN for the specified legal hold. The format of the ARN depends on the resource type.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

The ID of the legal hold.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_selectionTypes::RecoveryPointSelection

The criteria to assign a set of resources, such as resource types or backup vaults.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#retain_record_untilTime

The date and time until which the legal hold record is retained.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the legal hold.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end

#titleString

The title of the legal hold.



3936
3937
3938
3939
3940
3941
3942
3943
3944
3945
3946
3947
3948
3949
# File 'lib/aws-sdk-backup/types.rb', line 3936

class GetLegalHoldOutput < Struct.new(
  :title,
  :status,
  :description,
  :cancel_description,
  :legal_hold_id,
  :legal_hold_arn,
  :creation_date,
  :cancellation_date,
  :retain_record_until,
  :recovery_point_selection)
  SENSITIVE = []
  include Aws::Structure
end