Class: Aws::Backup::Types::GetPITRMalwareScanResultsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetPITRMalwareScanResultsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_scan_job_time ⇒ Time
The completion time of the most recent scan job that covered the specified point in time.
-
#scan_end_time ⇒ Time
The point in time that was queried.
-
#scan_id ⇒ String
The scan ID generated by Amazon GuardDuty for the corresponding Scan Job ID request from Backup.
-
#scan_mode ⇒ String
Specifies the scan type used for the scan job.
-
#scan_result ⇒ Types::ScanResultInfo
Contains the
ScanResultStatusfor the scan and returnsTHREATS_FOUND,NO_THREATS_FOUND, orUNKNOWN.
Instance Attribute Details
#last_scan_job_time ⇒ Time
The completion time of the most recent scan job that covered the specified point in time.
5063 5064 5065 5066 5067 5068 5069 5070 5071 |
# File 'lib/aws-sdk-backup/types.rb', line 5063 class GetPITRMalwareScanResultsOutput < Struct.new( :scan_end_time, :scan_result, :last_scan_job_time, :scan_id, :scan_mode) SENSITIVE = [] include Aws::Structure end |
#scan_end_time ⇒ Time
The point in time that was queried. This echoes back the time specified in the request.
5063 5064 5065 5066 5067 5068 5069 5070 5071 |
# File 'lib/aws-sdk-backup/types.rb', line 5063 class GetPITRMalwareScanResultsOutput < Struct.new( :scan_end_time, :scan_result, :last_scan_job_time, :scan_id, :scan_mode) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The scan ID generated by Amazon GuardDuty for the corresponding Scan Job ID request from Backup.
5063 5064 5065 5066 5067 5068 5069 5070 5071 |
# File 'lib/aws-sdk-backup/types.rb', line 5063 class GetPITRMalwareScanResultsOutput < Struct.new( :scan_end_time, :scan_result, :last_scan_job_time, :scan_id, :scan_mode) SENSITIVE = [] include Aws::Structure end |
#scan_mode ⇒ String
Specifies the scan type used for the scan job.
5063 5064 5065 5066 5067 5068 5069 5070 5071 |
# File 'lib/aws-sdk-backup/types.rb', line 5063 class GetPITRMalwareScanResultsOutput < Struct.new( :scan_end_time, :scan_result, :last_scan_job_time, :scan_id, :scan_mode) SENSITIVE = [] include Aws::Structure end |
#scan_result ⇒ Types::ScanResultInfo
Contains the ScanResultStatus for the scan and returns
THREATS_FOUND, NO_THREATS_FOUND, or UNKNOWN.
5063 5064 5065 5066 5067 5068 5069 5070 5071 |
# File 'lib/aws-sdk-backup/types.rb', line 5063 class GetPITRMalwareScanResultsOutput < Struct.new( :scan_end_time, :scan_result, :last_scan_job_time, :scan_id, :scan_mode) SENSITIVE = [] include Aws::Structure end |