Class: Aws::Backup::Types::GetRecoveryPointIndexDetailsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetRecoveryPointIndexDetailsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_arn ⇒ String
An ARN that uniquely identifies the backup vault where the recovery point index is stored.
-
#index_completion_date ⇒ Time
The date and time that a backup index finished creation, in Unix format and Coordinated Universal Time (UTC).
-
#index_creation_date ⇒ Time
The date and time that a backup index was created, in Unix format and Coordinated Universal Time (UTC).
-
#index_deletion_date ⇒ Time
The date and time that a backup index was deleted, in Unix format and Coordinated Universal Time (UTC).
-
#index_status ⇒ String
This is the current status for the backup index associated with the specified recovery point.
-
#index_status_message ⇒ String
A detailed message explaining the status of a backup index associated with the recovery point.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45. -
#source_resource_arn ⇒ String
A string of the Amazon Resource Name (ARN) that uniquely identifies the source resource.
-
#total_items_indexed ⇒ Integer
Count of items within the backup index associated with the recovery point.
Instance Attribute Details
#backup_vault_arn ⇒ String
An ARN that uniquely identifies the backup vault where the recovery point index is stored.
For example,
arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#index_completion_date ⇒ Time
The date and time that a backup index finished creation, in Unix
format and Coordinated Universal Time (UTC). The value of
CreationDate is accurate to milliseconds. For example, the value
1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#index_creation_date ⇒ Time
The date and time that a backup index was created, in Unix format
and Coordinated Universal Time (UTC). The value of CreationDate is
accurate to milliseconds. For example, the value 1516925490.087
represents Friday, January 26, 2018 12:11:30.087 AM.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#index_deletion_date ⇒ Time
The date and time that a backup index was deleted, in Unix format
and Coordinated Universal Time (UTC). The value of CreationDate is
accurate to milliseconds. For example, the value 1516925490.087
represents Friday, January 26, 2018 12:11:30.087 AM.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#index_status ⇒ String
This is the current status for the backup index associated with the specified recovery point.
Statuses are: PENDING | ACTIVE | FAILED | DELETING
A recovery point with an index that has the status of ACTIVE can
be included in a search.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#index_status_message ⇒ String
A detailed message explaining the status of a backup index associated with the recovery point.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#source_resource_arn ⇒ String
A string of the Amazon Resource Name (ARN) that uniquely identifies the source resource.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |
#total_items_indexed ⇒ Integer
Count of items within the backup index associated with the recovery point.
5156 5157 5158 5159 5160 5161 5162 5163 5164 5165 5166 5167 5168 |
# File 'lib/aws-sdk-backup/types.rb', line 5156 class GetRecoveryPointIndexDetailsOutput < Struct.new( :recovery_point_arn, :backup_vault_arn, :source_resource_arn, :index_creation_date, :index_deletion_date, :index_completion_date, :index_status, :index_status_message, :total_items_indexed) SENSITIVE = [] include Aws::Structure end |