Class: Aws::Backup::Types::LegalHold
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::LegalHold
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
A legal hold is an administrative tool that helps prevent backups from being deleted while under a hold. While the hold is in place, backups under a hold cannot be deleted and lifecycle policies that would alter the backup status (such as transition to cold storage) are delayed until the legal hold is removed. A backup can have more than one legal hold. Legal holds are applied to one or more backups (also known as recovery points). These backups can be filtered by resource types and by resource IDs.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cancellation_date ⇒ Time
The time when the legal hold was cancelled.
-
#creation_date ⇒ Time
The time when the legal hold was created.
-
#description ⇒ String
The description of a legal hold.
-
#legal_hold_arn ⇒ String
The Amazon Resource Name (ARN) of the legal hold; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45. -
#legal_hold_id ⇒ String
The ID of the legal hold.
-
#status ⇒ String
The status of the legal hold.
-
#title ⇒ String
The title of a legal hold.
Instance Attribute Details
#cancellation_date ⇒ Time
The time when the legal hold was cancelled.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The time when the legal hold was created.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of a legal hold.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#legal_hold_arn ⇒ String
The Amazon Resource Name (ARN) of the legal hold; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#legal_hold_id ⇒ String
The ID of the legal hold.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the legal hold.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |
#title ⇒ String
The title of a legal hold.
5745 5746 5747 5748 5749 5750 5751 5752 5753 5754 5755 |
# File 'lib/aws-sdk-backup/types.rb', line 5745 class LegalHold < Struct.new( :title, :status, :description, :legal_hold_id, :legal_hold_arn, :creation_date, :cancellation_date) SENSITIVE = [] include Aws::Structure end |