Class: Aws::Backup::Types::ListBackupAccessPointsByResourceRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of items to be returned.

Returns:

  • (Integer)


5983
5984
5985
5986
5987
5988
5989
# File 'lib/aws-sdk-backup/types.rb', line 5983

class ListBackupAccessPointsByResourceRequest < Struct.new(
  :max_results,
  :next_token,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


5983
5984
5985
5986
5987
5988
5989
# File 'lib/aws-sdk-backup/types.rb', line 5983

class ListBackupAccessPointsByResourceRequest < Struct.new(
  :max_results,
  :next_token,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the resource whose backup access points you want to list.

Returns:

  • (String)


5983
5984
5985
5986
5987
5988
5989
# File 'lib/aws-sdk-backup/types.rb', line 5983

class ListBackupAccessPointsByResourceRequest < Struct.new(
  :max_results,
  :next_token,
  :resource_arn)
  SENSITIVE = []
  include Aws::Structure
end