Class: Aws::Backup::Types::ListBackupAccessPointsByResourceResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_access_pointsArray<Types::ListAccessPointsMember>

A list of backup access points, each containing metadata such as its name, ARN, status, and associated recovery point.

Returns:



6005
6006
6007
6008
6009
6010
# File 'lib/aws-sdk-backup/types.rb', line 6005

class ListBackupAccessPointsByResourceResponse < Struct.new(
  :backup_access_points,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


6005
6006
6007
6008
6009
6010
# File 'lib/aws-sdk-backup/types.rb', line 6005

class ListBackupAccessPointsByResourceResponse < Struct.new(
  :backup_access_points,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end