Class: Aws::Backup::Types::ListBackupAccessPointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupAccessPointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to be returned.
6025 6026 6027 6028 6029 6030 |
# File 'lib/aws-sdk-backup/types.rb', line 6025 class ListBackupAccessPointsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6025 6026 6027 6028 6029 6030 |
# File 'lib/aws-sdk-backup/types.rb', line 6025 class ListBackupAccessPointsRequest < Struct.new( :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |