Class: Aws::Backup::Types::ListBackupJobSummariesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupJobSummariesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aggregation_period ⇒ String
The period for the returned results.
-
#backup_job_summaries ⇒ Array<Types::BackupJobSummary>
The summary information.
-
#next_token ⇒ String
The next item following a partial list of returned resources.
Instance Attribute Details
#aggregation_period ⇒ String
The period for the returned results.
-
ONE_DAY- The daily job count for the prior 14 days. -
SEVEN_DAYS- The aggregated job count for the prior 7 days. -
FOURTEEN_DAYS- The aggregated job count for prior 14 days.
6183 6184 6185 6186 6187 6188 6189 |
# File 'lib/aws-sdk-backup/types.rb', line 6183 class ListBackupJobSummariesOutput < Struct.new( :backup_job_summaries, :aggregation_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#backup_job_summaries ⇒ Array<Types::BackupJobSummary>
The summary information.
6183 6184 6185 6186 6187 6188 6189 |
# File 'lib/aws-sdk-backup/types.rb', line 6183 class ListBackupJobSummariesOutput < Struct.new( :backup_job_summaries, :aggregation_period, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned resources. For
example, if a request is made to return MaxResults number of
resources, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6183 6184 6185 6186 6187 6188 6189 |
# File 'lib/aws-sdk-backup/types.rb', line 6183 class ListBackupJobSummariesOutput < Struct.new( :backup_job_summaries, :aggregation_period, :next_token) SENSITIVE = [] include Aws::Structure end |