Class: Aws::Backup::Types::ListBackupJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupJobsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#by_account_id ⇒ String
The account ID to list the jobs from.
-
#by_backup_vault_name ⇒ String
Returns only backup jobs that will be stored in the specified backup vault.
-
#by_complete_after ⇒ Time
Returns only backup jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).
-
#by_complete_before ⇒ Time
Returns only backup jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).
-
#by_created_after ⇒ Time
Returns only backup jobs that were created after the specified date.
-
#by_created_before ⇒ Time
Returns only backup jobs that were created before the specified date.
-
#by_message_category ⇒ String
This is an optional parameter that can be used to filter out jobs with a MessageCategory which matches the value you input.
-
#by_parent_job_id ⇒ String
This is a filter to list child (nested) jobs based on parent job ID.
-
#by_resource_arn ⇒ String
Returns only backup jobs that match the specified resource Amazon Resource Name (ARN).
-
#by_resource_type ⇒ String
Returns only backup jobs for the specified resources:.
-
#by_state ⇒ String
Returns only backup jobs that are in the specified state.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#by_account_id ⇒ String
The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID.
If used from an Organizations management account, passing *
returns all jobs across the organization.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_backup_vault_name ⇒ String
Returns only backup jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_complete_after ⇒ Time
Returns only backup jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_complete_before ⇒ Time
Returns only backup jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_created_after ⇒ Time
Returns only backup jobs that were created after the specified date.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_created_before ⇒ Time
Returns only backup jobs that were created before the specified date.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_message_category ⇒ String
This is an optional parameter that can be used to filter out jobs with a MessageCategory which matches the value you input.
Example strings may include AccessDenied, SUCCESS,
AGGREGATE_ALL, and InvalidParameters.
View Monitoring
The wildcard () returns count of all message categories.
AGGREGATE_ALL aggregates job counts for all message categories and
returns the sum.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_parent_job_id ⇒ String
This is a filter to list child (nested) jobs based on parent job ID.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_resource_arn ⇒ String
Returns only backup jobs that match the specified resource Amazon Resource Name (ARN).
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_resource_type ⇒ String
Returns only backup jobs for the specified resources:
-
Aurorafor Amazon Aurora -
CloudFormationfor CloudFormation -
DocumentDBfor Amazon DocumentDB (with MongoDB compatibility) -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
EKSfor Amazon Elastic Kubernetes Service -
FSxfor Amazon FSx -
Neptunefor Amazon Neptune -
RDSfor Amazon Relational Database Service -
Redshiftfor Amazon Redshift -
S3for Amazon Simple Storage Service (Amazon S3) -
SAP HANA on Amazon EC2for SAP HANA databases on Amazon Elastic Compute Cloud instances -
Storage Gatewayfor Storage Gateway -
Timestreamfor Amazon Timestream -
VirtualMachinefor VMware virtual machines
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#by_state ⇒ String
Returns only backup jobs that are in the specified state.
Completed with issues is a status found only in the Backup
console. For API, this status refers to jobs with a state of
COMPLETED and a MessageCategory with a value other than
SUCCESS; that is, the status is completed but comes with a status
message.
To obtain the job count for Completed with issues, run two GET
requests, and subtract the second, smaller number:
GET /backup-jobs/?state=COMPLETED
GET /backup-jobs/?messageCategory=SUCCESS&state=COMPLETED
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6322 6323 6324 6325 6326 6327 6328 6329 6330 6331 6332 6333 6334 6335 6336 6337 6338 |
# File 'lib/aws-sdk-backup/types.rb', line 6322 class ListBackupJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_backup_vault_name, :by_created_before, :by_created_after, :by_resource_type, :by_account_id, :by_complete_after, :by_complete_before, :by_parent_job_id, :by_message_category) SENSITIVE = [] include Aws::Structure end |