Class: Aws::Backup::Types::ListBackupPlanTemplatesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupPlanTemplatesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to return.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to return.
6374 6375 6376 6377 6378 6379 |
# File 'lib/aws-sdk-backup/types.rb', line 6374 class ListBackupPlanTemplatesInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6374 6375 6376 6377 6378 6379 |
# File 'lib/aws-sdk-backup/types.rb', line 6374 class ListBackupPlanTemplatesInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |