Class: Aws::Backup::Types::ListBackupPlanTemplatesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupPlanTemplatesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_plan_templates_list ⇒ Array<Types::BackupPlanTemplatesListMember>
An array of template list items containing metadata about your saved templates.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#backup_plan_templates_list ⇒ Array<Types::BackupPlanTemplatesListMember>
An array of template list items containing metadata about your saved templates.
5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-backup/types.rb', line 5886 class ListBackupPlanTemplatesOutput < Struct.new( :next_token, :backup_plan_templates_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
5886 5887 5888 5889 5890 5891 |
# File 'lib/aws-sdk-backup/types.rb', line 5886 class ListBackupPlanTemplatesOutput < Struct.new( :next_token, :backup_plan_templates_list) SENSITIVE = [] include Aws::Structure end |