Class: Aws::Backup::Types::ListBackupPlansInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupPlansInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#include_deleted ⇒ Boolean
A Boolean value with a default value of
FALSEthat returns deleted backup plans when set toTRUE. -
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#include_deleted ⇒ Boolean
A Boolean value with a default value of FALSE that returns deleted
backup plans when set to TRUE.
6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-backup/types.rb', line 6466 class ListBackupPlansInput < Struct.new( :next_token, :max_results, :include_deleted) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-backup/types.rb', line 6466 class ListBackupPlansInput < Struct.new( :next_token, :max_results, :include_deleted) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/aws-sdk-backup/types.rb', line 6466 class ListBackupPlansInput < Struct.new( :next_token, :max_results, :include_deleted) SENSITIVE = [] include Aws::Structure end |