Class: Aws::Backup::Types::ListBackupPlansOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plans_listArray<Types::BackupPlansListMember>

Information about the backup plans.

Returns:



6487
6488
6489
6490
6491
6492
# File 'lib/aws-sdk-backup/types.rb', line 6487

class ListBackupPlansOutput < Struct.new(
  :next_token,
  :backup_plans_list)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


6487
6488
6489
6490
6491
6492
# File 'lib/aws-sdk-backup/types.rb', line 6487

class ListBackupPlansOutput < Struct.new(
  :next_token,
  :backup_plans_list)
  SENSITIVE = []
  include Aws::Structure
end