Class: Aws::Backup::Types::ListBackupSelectionsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupSelectionsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_selections_list ⇒ Array<Types::BackupSelectionsListMember>
An array of backup selection list items containing metadata about each resource in the list.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#backup_selections_list ⇒ Array<Types::BackupSelectionsListMember>
An array of backup selection list items containing metadata about each resource in the list.
6533 6534 6535 6536 6537 6538 |
# File 'lib/aws-sdk-backup/types.rb', line 6533 class ListBackupSelectionsOutput < Struct.new( :next_token, :backup_selections_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6533 6534 6535 6536 6537 6538 |
# File 'lib/aws-sdk-backup/types.rb', line 6533 class ListBackupSelectionsOutput < Struct.new( :next_token, :backup_selections_list) SENSITIVE = [] include Aws::Structure end |