Class: Aws::Backup::Types::ListBackupVaultsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupVaultsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#by_shared ⇒ Boolean
This parameter will sort the list of vaults by shared vaults.
-
#by_vault_type ⇒ String
This parameter will sort the list of vaults by vault type.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#by_shared ⇒ Boolean
This parameter will sort the list of vaults by shared vaults.
6561 6562 6563 6564 6565 6566 6567 6568 |
# File 'lib/aws-sdk-backup/types.rb', line 6561 class ListBackupVaultsInput < Struct.new( :by_vault_type, :by_shared, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#by_vault_type ⇒ String
This parameter will sort the list of vaults by vault type.
6561 6562 6563 6564 6565 6566 6567 6568 |
# File 'lib/aws-sdk-backup/types.rb', line 6561 class ListBackupVaultsInput < Struct.new( :by_vault_type, :by_shared, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
6561 6562 6563 6564 6565 6566 6567 6568 |
# File 'lib/aws-sdk-backup/types.rb', line 6561 class ListBackupVaultsInput < Struct.new( :by_vault_type, :by_shared, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6561 6562 6563 6564 6565 6566 6567 6568 |
# File 'lib/aws-sdk-backup/types.rb', line 6561 class ListBackupVaultsInput < Struct.new( :by_vault_type, :by_shared, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |