Class: Aws::Backup::Types::ListBackupVaultsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupVaultsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_list ⇒ Array<Types::BackupVaultListMember>
An array of backup vault list members containing vault metadata, including Amazon Resource Name (ARN), display name, creation date, number of saved recovery points, and encryption information if the resources saved in the backup vault are encrypted.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#backup_vault_list ⇒ Array<Types::BackupVaultListMember>
An array of backup vault list members containing vault metadata, including Amazon Resource Name (ARN), display name, creation date, number of saved recovery points, and encryption information if the resources saved in the backup vault are encrypted.
6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-backup/types.rb', line 6586 class ListBackupVaultsOutput < Struct.new( :backup_vault_list, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
6586 6587 6588 6589 6590 6591 |
# File 'lib/aws-sdk-backup/types.rb', line 6586 class ListBackupVaultsOutput < Struct.new( :backup_vault_list, :next_token) SENSITIVE = [] include Aws::Structure end |