Class: Aws::Backup::Types::ListCopyJobsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListCopyJobsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#by_account_id ⇒ String
The account ID to list the jobs from.
-
#by_complete_after ⇒ Time
Returns only copy jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).
-
#by_complete_before ⇒ Time
Returns only copy jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).
-
#by_created_after ⇒ Time
Returns only copy jobs that were created after the specified date.
-
#by_created_before ⇒ Time
Returns only copy jobs that were created before the specified date.
-
#by_destination_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a source backup vault to copy from; for example,
arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault. -
#by_message_category ⇒ String
This is an optional parameter that can be used to filter out jobs with a MessageCategory which matches the value you input.
-
#by_parent_job_id ⇒ String
This is a filter to list child (nested) jobs based on parent job ID.
-
#by_resource_arn ⇒ String
Returns only copy jobs that match the specified resource Amazon Resource Name (ARN).
-
#by_resource_type ⇒ String
Returns only backup jobs for the specified resources:.
-
#by_source_recovery_point_arn ⇒ String
Filters copy jobs by the specified source recovery point ARN.
-
#by_state ⇒ String
Returns only copy jobs that are in the specified state.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#by_account_id ⇒ String
The account ID to list the jobs from. Returns only copy jobs associated with the specified account ID.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_complete_after ⇒ Time
Returns only copy jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_complete_before ⇒ Time
Returns only copy jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_created_after ⇒ Time
Returns only copy jobs that were created after the specified date.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_created_before ⇒ Time
Returns only copy jobs that were created before the specified date.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_destination_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a source
backup vault to copy from; for example,
arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_message_category ⇒ String
This is an optional parameter that can be used to filter out jobs with a MessageCategory which matches the value you input.
Example strings may include AccessDenied, SUCCESS,
AGGREGATE_ALL, and INVALIDPARAMETERS.
View Monitoring for a list of accepted strings.
The the value ANY returns count of all message categories.
AGGREGATE_ALL aggregates job counts for all message categories and
returns the sum.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_parent_job_id ⇒ String
This is a filter to list child (nested) jobs based on parent job ID.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_resource_arn ⇒ String
Returns only copy jobs that match the specified resource Amazon Resource Name (ARN).
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_resource_type ⇒ String
Returns only backup jobs for the specified resources:
-
Aurorafor Amazon Aurora -
CloudFormationfor CloudFormation -
DocumentDBfor Amazon DocumentDB (with MongoDB compatibility) -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
EKSfor Amazon Elastic Kubernetes Service -
FSxfor Amazon FSx -
Neptunefor Amazon Neptune -
RDSfor Amazon Relational Database Service -
Redshiftfor Amazon Redshift -
S3for Amazon Simple Storage Service (Amazon S3) -
SAP HANA on Amazon EC2for SAP HANA databases on Amazon Elastic Compute Cloud instances -
Storage Gatewayfor Storage Gateway -
Timestreamfor Amazon Timestream -
VirtualMachinefor VMware virtual machines
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_source_recovery_point_arn ⇒ String
Filters copy jobs by the specified source recovery point ARN.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_state ⇒ String
Returns only copy jobs that are in the specified state.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 |
# File 'lib/aws-sdk-backup/types.rb', line 6837 class ListCopyJobsInput < Struct.new( :next_token, :max_results, :by_resource_arn, :by_state, :by_created_before, :by_created_after, :by_resource_type, :by_destination_vault_arn, :by_account_id, :by_complete_before, :by_complete_after, :by_parent_job_id, :by_message_category, :by_source_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |