Class: Aws::Backup::Types::ListLegalHoldsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListLegalHoldsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of resource list items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned resources.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of resource list items to be returned.
7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-backup/types.rb', line 7015 class ListLegalHoldsInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned resources. For
example, if a request is made to return MaxResults number of
resources, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7015 7016 7017 7018 7019 7020 |
# File 'lib/aws-sdk-backup/types.rb', line 7015 class ListLegalHoldsInput < Struct.new( :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |