Class: Aws::Backup::Types::ListLegalHoldsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListLegalHoldsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#legal_holds ⇒ Array<Types::LegalHold>
This is an array of returned legal holds, both active and previous.
-
#next_token ⇒ String
The next item following a partial list of returned resources.
Instance Attribute Details
#legal_holds ⇒ Array<Types::LegalHold>
This is an array of returned legal holds, both active and previous.
7035 7036 7037 7038 7039 7040 |
# File 'lib/aws-sdk-backup/types.rb', line 7035 class ListLegalHoldsOutput < Struct.new( :next_token, :legal_holds) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned resources. For
example, if a request is made to return MaxResults number of
resources, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7035 7036 7037 7038 7039 7040 |
# File 'lib/aws-sdk-backup/types.rb', line 7035 class ListLegalHoldsOutput < Struct.new( :next_token, :legal_holds) SENSITIVE = [] include Aws::Structure end |