Class: Aws::Backup::Types::ListProtectedResourcesByBackupVaultOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListProtectedResourcesByBackupVaultOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#results ⇒ Array<Types::ProtectedResource>
These are the results returned for the request ListProtectedResourcesByBackupVault.
Instance Attribute Details
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-backup/types.rb', line 7088 class ListProtectedResourcesByBackupVaultOutput < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |
#results ⇒ Array<Types::ProtectedResource>
These are the results returned for the request ListProtectedResourcesByBackupVault.
7088 7089 7090 7091 7092 7093 |
# File 'lib/aws-sdk-backup/types.rb', line 7088 class ListProtectedResourcesByBackupVaultOutput < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |