Class: Aws::Backup::Types::ListProtectedResourcesOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListProtectedResourcesOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#results ⇒ Array<Types::ProtectedResource>
An array of resources successfully backed up by Backup including the time the resource was saved, an Amazon Resource Name (ARN) of the resource, and a resource type.
Instance Attribute Details
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7130 7131 7132 7133 7134 7135 |
# File 'lib/aws-sdk-backup/types.rb', line 7130 class ListProtectedResourcesOutput < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |
#results ⇒ Array<Types::ProtectedResource>
An array of resources successfully backed up by Backup including the time the resource was saved, an Amazon Resource Name (ARN) of the resource, and a resource type.
7130 7131 7132 7133 7134 7135 |
# File 'lib/aws-sdk-backup/types.rb', line 7130 class ListProtectedResourcesOutput < Struct.new( :results, :next_token) SENSITIVE = [] include Aws::Structure end |