Class: Aws::Backup::Types::ListRecoveryPointsByBackupVaultInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_account_idString

This parameter will sort the list of recovery points by account ID.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Backup vault name might not be available when a supported service creates the backup.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_backup_plan_idString

Returns only recovery points that match the specified backup plan ID.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_created_afterTime

Returns only recovery points that were created after the specified timestamp.

Returns:

  • (Time)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_created_beforeTime

Returns only recovery points that were created before the specified timestamp.

Returns:

  • (Time)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_parent_recovery_point_arnString

This returns only recovery points that match the specified parent (composite) recovery point Amazon Resource Name (ARN).

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_resource_arnString

Returns only recovery points that match the specified resource Amazon Resource Name (ARN).

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#by_resource_typeString

Returns only recovery points that match the specified resource type(s):

  • Aurora for Amazon Aurora

  • CloudFormation for CloudFormation

  • DocumentDB for Amazon DocumentDB (with MongoDB compatibility)

  • DynamoDB for Amazon DynamoDB

  • EBS for Amazon Elastic Block Store

  • EC2 for Amazon Elastic Compute Cloud

  • EFS for Amazon Elastic File System

  • EKS for Amazon Elastic Kubernetes Service

  • FSx for Amazon FSx

  • Neptune for Amazon Neptune

  • RDS for Amazon Relational Database Service

  • Redshift for Amazon Redshift

  • S3 for Amazon Simple Storage Service (Amazon S3)

  • SAP HANA on Amazon EC2 for SAP HANA databases on Amazon Elastic Compute Cloud instances

  • Storage Gateway for Storage Gateway

  • Timestream for Amazon Timestream

  • VirtualMachine for VMware virtual machines

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to be returned.

Returns:

  • (Integer)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


7231
7232
7233
7234
7235
7236
7237
7238
7239
7240
7241
7242
7243
7244
# File 'lib/aws-sdk-backup/types.rb', line 7231

class ListRecoveryPointsByBackupVaultInput < Struct.new(
  :backup_vault_name,
  :backup_vault_account_id,
  :next_token,
  :max_results,
  :by_resource_arn,
  :by_resource_type,
  :by_backup_plan_id,
  :by_created_before,
  :by_created_after,
  :by_parent_recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end