Class: Aws::Backup::Types::ListRecoveryPointsByLegalHoldInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

The ID of the legal hold.

Returns:

  • (String)


7284
7285
7286
7287
7288
7289
7290
# File 'lib/aws-sdk-backup/types.rb', line 7284

class ListRecoveryPointsByLegalHoldInput < Struct.new(
  :legal_hold_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of resource list items to be returned.

Returns:

  • (Integer)


7284
7285
7286
7287
7288
7289
7290
# File 'lib/aws-sdk-backup/types.rb', line 7284

class ListRecoveryPointsByLegalHoldInput < Struct.new(
  :legal_hold_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned resources. For example, if a request is made to return MaxResults number of resources, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


7284
7285
7286
7287
7288
7289
7290
# File 'lib/aws-sdk-backup/types.rb', line 7284

class ListRecoveryPointsByLegalHoldInput < Struct.new(
  :legal_hold_id,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end