Class: Aws::Backup::Types::ListRecoveryPointsByResourceInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListRecoveryPointsByResourceInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#managed_by_aws_backup_only ⇒ Boolean
This attribute filters recovery points based on ownership.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#resource_arn ⇒ String
An ARN that uniquely identifies a resource.
Instance Attribute Details
#managed_by_aws_backup_only ⇒ Boolean
This attribute filters recovery points based on ownership.
If this is set to TRUE, the response will contain recovery points
associated with the selected resources that are managed by Backup.
If this is set to FALSE, the response will contain all recovery
points associated with the selected resource, except for EBS
snapshots copied within the same Region and account.
Type: Boolean
7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-backup/types.rb', line 7344 class ListRecoveryPointsByResourceInput < Struct.new( :resource_arn, :next_token, :max_results, :managed_by_aws_backup_only) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-backup/types.rb', line 7344 class ListRecoveryPointsByResourceInput < Struct.new( :resource_arn, :next_token, :max_results, :managed_by_aws_backup_only) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-backup/types.rb', line 7344 class ListRecoveryPointsByResourceInput < Struct.new( :resource_arn, :next_token, :max_results, :managed_by_aws_backup_only) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
An ARN that uniquely identifies a resource. The format of the ARN depends on the resource type.
7344 7345 7346 7347 7348 7349 7350 7351 |
# File 'lib/aws-sdk-backup/types.rb', line 7344 class ListRecoveryPointsByResourceInput < Struct.new( :resource_arn, :next_token, :max_results, :managed_by_aws_backup_only) SENSITIVE = [] include Aws::Structure end |