Class: Aws::Backup::Types::ListScanJobsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#by_account_idString

The account ID to list the jobs from. Returns only backup jobs associated with the specified account ID.

If used from an Amazon Web Services Organizations management account, passing * returns all jobs across the organization.

Pattern: ^[0-9]{12}$

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_backup_vault_nameString

Returns only scan jobs that will be stored in the specified backup vault. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Pattern: ^[a-zA-Z0-9\-\_\.]{2,50}$

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_complete_afterTime

Returns only scan jobs completed after a date expressed in Unix format and Coordinated Universal Time (UTC).

Returns:

  • (Time)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_complete_beforeTime

Returns only backup jobs completed before a date expressed in Unix format and Coordinated Universal Time (UTC).

Returns:

  • (Time)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_malware_scannerString

Returns only the scan jobs for the specified malware scanner. Currently only supports GUARDDUTY.

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_recovery_point_arnString

Returns only the scan jobs that are ran against the specified recovery point.

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_resource_arnString

Returns only scan jobs that match the specified resource Amazon Resource Name (ARN).

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_resource_typeString

Returns restore testing selections by the specified restore testing plan name.

  • EBSfor Amazon Elastic Block Store

  • EC2for Amazon Elastic Compute Cloud

  • S3for Amazon Simple Storage Service (Amazon S3)

Pattern: ^[a-zA-Z0-9\-\_\.]{1,50}$

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_scan_result_statusString

Returns only the scan jobs for the specified scan results:

  • THREATS_FOUND

  • NO_THREATS_FOUND

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#by_stateString

Returns only the scan jobs for the specified scanning job state.

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of items to be returned.

Valid Range: Minimum value of 1. Maximum value of 1000.

Returns:

  • (Integer)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.

Returns:

  • (String)


8119
8120
8121
8122
8123
8124
8125
8126
8127
8128
8129
8130
8131
8132
8133
8134
# File 'lib/aws-sdk-backup/types.rb', line 8119

class ListScanJobsInput < Struct.new(
  :by_account_id,
  :by_backup_vault_name,
  :by_complete_after,
  :by_complete_before,
  :by_malware_scanner,
  :by_recovery_point_arn,
  :by_resource_arn,
  :by_resource_type,
  :by_scan_result_status,
  :by_state,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end