Class: Aws::Backup::Types::ProtectedResourceConditions
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ProtectedResourceConditions
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
The conditions that you define for resources in your restore testing plan using tags.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#string_equals ⇒ Array<Types::KeyValue>
Filters the values of your tagged resources for only those resources that you tagged with the same value.
-
#string_not_equals ⇒ Array<Types::KeyValue>
Filters the values of your tagged resources for only those resources that you tagged that do not have the same value.
Instance Attribute Details
#string_equals ⇒ Array<Types::KeyValue>
Filters the values of your tagged resources for only those resources that you tagged with the same value. Also called “exact matching.”
7935 7936 7937 7938 7939 7940 |
# File 'lib/aws-sdk-backup/types.rb', line 7935 class ProtectedResourceConditions < Struct.new( :string_equals, :string_not_equals) SENSITIVE = [] include Aws::Structure end |
#string_not_equals ⇒ Array<Types::KeyValue>
Filters the values of your tagged resources for only those resources that you tagged that do not have the same value. Also called “negated matching.”
7935 7936 7937 7938 7939 7940 |
# File 'lib/aws-sdk-backup/types.rb', line 7935 class ProtectedResourceConditions < Struct.new( :string_equals, :string_not_equals) SENSITIVE = [] include Aws::Structure end |