Class: Aws::Backup::Types::PutBackupVaultAccessPolicyInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Returns:

  • (String)


8355
8356
8357
8358
8359
8360
# File 'lib/aws-sdk-backup/types.rb', line 8355

class PutBackupVaultAccessPolicyInput < Struct.new(
  :backup_vault_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The backup vault access policy document in JSON format.

Returns:

  • (String)


8355
8356
8357
8358
8359
8360
# File 'lib/aws-sdk-backup/types.rb', line 8355

class PutBackupVaultAccessPolicyInput < Struct.new(
  :backup_vault_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end