Class: Aws::Backup::Types::RecoveryPointCreator

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Contains information about the backup plan and rule that Backup used to initiate the recovery point backup.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_plan_arnString

An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example, ‘arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50`.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_plan_idString

Uniquely identifies a backup plan.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_plan_nameString

The name of the backup plan that created this recovery point. This provides human-readable context about which backup plan was responsible for the backup job.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_plan_versionString

Version IDs are unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. They cannot be edited.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_rule_cronString

The cron expression that defines the schedule for the backup rule. This shows the frequency and timing of when backups are automatically triggered.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_rule_idString

Uniquely identifies a rule used to schedule the backup of a selection of resources.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_rule_nameString

The name of the backup rule within the backup plan that created this recovery point. This helps identify which specific rule triggered the backup job.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end

#backup_rule_timezoneString

The timezone used for the backup rule schedule. This provides context for when backups are scheduled to run in the specified timezone.

Returns:

  • (String)


8398
8399
8400
8401
8402
8403
8404
8405
8406
8407
8408
8409
# File 'lib/aws-sdk-backup/types.rb', line 8398

class RecoveryPointCreator < Struct.new(
  :backup_plan_id,
  :backup_plan_arn,
  :backup_plan_name,
  :backup_plan_version,
  :backup_rule_id,
  :backup_rule_name,
  :backup_rule_cron,
  :backup_rule_timezone)
  SENSITIVE = []
  include Aws::Structure
end