Class: Aws::Backup::Types::ReportDeliveryChannel
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ReportDeliveryChannel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains information from your report plan about where to deliver your reports, specifically your Amazon S3 bucket name, S3 key prefix, and the formats of your reports.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#formats ⇒ Array<String>
The format of your reports: ‘CSV`, `JSON`, or both.
-
#s3_bucket_name ⇒ String
The unique name of the S3 bucket that receives your reports.
-
#s3_key_prefix ⇒ String
The prefix for where Backup Audit Manager delivers your reports to Amazon S3.
Instance Attribute Details
#formats ⇒ Array<String>
The format of your reports: ‘CSV`, `JSON`, or both. If not specified, the default format is `CSV`.
8503 8504 8505 8506 8507 8508 8509 |
# File 'lib/aws-sdk-backup/types.rb', line 8503 class ReportDeliveryChannel < Struct.new( :s3_bucket_name, :s3_key_prefix, :formats) SENSITIVE = [] include Aws::Structure end |
#s3_bucket_name ⇒ String
The unique name of the S3 bucket that receives your reports.
8503 8504 8505 8506 8507 8508 8509 |
# File 'lib/aws-sdk-backup/types.rb', line 8503 class ReportDeliveryChannel < Struct.new( :s3_bucket_name, :s3_key_prefix, :formats) SENSITIVE = [] include Aws::Structure end |
#s3_key_prefix ⇒ String
The prefix for where Backup Audit Manager delivers your reports to Amazon S3. The prefix is this part of the following path: s3://your-bucket-name/‘prefix`/Backup/us-west-2/year/month/day/report-name. If not specified, there is no prefix.
8503 8504 8505 8506 8507 8508 8509 |
# File 'lib/aws-sdk-backup/types.rb', line 8503 class ReportDeliveryChannel < Struct.new( :s3_bucket_name, :s3_key_prefix, :formats) SENSITIVE = [] include Aws::Structure end |