Class: Aws::Backup::Types::ReportDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ReportDestination
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains information from your report job about your report destination.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#s3_bucket_name ⇒ String
The unique name of the Amazon S3 bucket that receives your reports.
-
#s3_keys ⇒ Array<String>
The object key that uniquely identifies your reports in your S3 bucket.
Instance Attribute Details
#s3_bucket_name ⇒ String
The unique name of the Amazon S3 bucket that receives your reports.
8525 8526 8527 8528 8529 8530 |
# File 'lib/aws-sdk-backup/types.rb', line 8525 class ReportDestination < Struct.new( :s3_bucket_name, :s3_keys) SENSITIVE = [] include Aws::Structure end |
#s3_keys ⇒ Array<String>
The object key that uniquely identifies your reports in your S3 bucket.
8525 8526 8527 8528 8529 8530 |
# File 'lib/aws-sdk-backup/types.rb', line 8525 class ReportDestination < Struct.new( :s3_bucket_name, :s3_keys) SENSITIVE = [] include Aws::Structure end |