Class: Aws::Backup::Types::ReportSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ReportSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains detailed information about a report setting.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#accounts ⇒ Array<String>
These are the accounts to be included in the report.
-
#framework_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the frameworks a report covers.
-
#number_of_frameworks ⇒ Integer
The number of frameworks a report covers.
-
#organization_units ⇒ Array<String>
These are the Organizational Units to be included in the report.
-
#regions ⇒ Array<String>
These are the Regions to be included in the report.
-
#report_template ⇒ String
Identifies the report template for the report.
Instance Attribute Details
#accounts ⇒ Array<String>
These are the accounts to be included in the report.
Use string value of ROOT to include all organizational units.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |
#framework_arns ⇒ Array<String>
The Amazon Resource Names (ARNs) of the frameworks a report covers.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |
#number_of_frameworks ⇒ Integer
The number of frameworks a report covers.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |
#organization_units ⇒ Array<String>
These are the Organizational Units to be included in the report.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |
#regions ⇒ Array<String>
These are the Regions to be included in the report.
Use the wildcard as the string value to include all Regions.
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |
#report_template ⇒ String
Identifies the report template for the report. Reports are built using a report template. The report templates are:
RESOURCE_COMPLIANCE_REPORT | CONTROL_COMPLIANCE_REPORT | BACKUP_JOB_REPORT | COPY_JOB_REPORT | RESTORE_JOB_REPORT | SCAN_JOB_REPORT
9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 |
# File 'lib/aws-sdk-backup/types.rb', line 9204 class ReportSetting < Struct.new( :report_template, :framework_arns, :number_of_frameworks, :accounts, :organization_units, :regions) SENSITIVE = [] include Aws::Structure end |