Class: Aws::Backup::Types::RestoreTestingSelectionForUpdate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::RestoreTestingSelectionForUpdate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
This contains metadata about a restore testing selection.
Constant Summary collapse
- SENSITIVE =
[:restore_metadata_overrides]
Instance Attribute Summary collapse
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Backup uses to create the target resource; for example:
arn:aws:iam::123456789012:role/S3Access. -
#protected_resource_arns ⇒ Array<String>
You can include a list of specific ARNs, such as
ProtectedResourceArns: ["arn:aws:...", "arn:aws:..."]or you can include a wildcard:ProtectedResourceArns: ["*"], but not both. -
#protected_resource_conditions ⇒ Types::ProtectedResourceConditions
The conditions that you define for resources in your restore testing plan using tags.
-
#restore_metadata_overrides ⇒ Hash<String,String>
You can override certain restore metadata keys by including the parameter
RestoreMetadataOverridesin the body ofRestoreTestingSelection. -
#validation_window_hours ⇒ Integer
This value represents the time, in hours, data is retained after a restore test so that optional validation can be completed.
Instance Attribute Details
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that Backup uses to
create the target resource; for example:
arn:aws:iam::123456789012:role/S3Access.
10176 10177 10178 10179 10180 10181 10182 10183 10184 |
# File 'lib/aws-sdk-backup/types.rb', line 10176 class RestoreTestingSelectionForUpdate < Struct.new( :iam_role_arn, :protected_resource_arns, :protected_resource_conditions, :restore_metadata_overrides, :validation_window_hours) SENSITIVE = [:restore_metadata_overrides] include Aws::Structure end |
#protected_resource_arns ⇒ Array<String>
You can include a list of specific ARNs, such as
ProtectedResourceArns: ["arn:aws:...", "arn:aws:..."] or you can
include a wildcard: ProtectedResourceArns: ["*"], but not both.
10176 10177 10178 10179 10180 10181 10182 10183 10184 |
# File 'lib/aws-sdk-backup/types.rb', line 10176 class RestoreTestingSelectionForUpdate < Struct.new( :iam_role_arn, :protected_resource_arns, :protected_resource_conditions, :restore_metadata_overrides, :validation_window_hours) SENSITIVE = [:restore_metadata_overrides] include Aws::Structure end |
#protected_resource_conditions ⇒ Types::ProtectedResourceConditions
The conditions that you define for resources in your restore testing plan using tags.
10176 10177 10178 10179 10180 10181 10182 10183 10184 |
# File 'lib/aws-sdk-backup/types.rb', line 10176 class RestoreTestingSelectionForUpdate < Struct.new( :iam_role_arn, :protected_resource_arns, :protected_resource_conditions, :restore_metadata_overrides, :validation_window_hours) SENSITIVE = [:restore_metadata_overrides] include Aws::Structure end |
#restore_metadata_overrides ⇒ Hash<String,String>
You can override certain restore metadata keys by including the
parameter RestoreMetadataOverrides in the body of
RestoreTestingSelection. Key values are not case sensitive.
See the complete list of restore testing inferred metadata.
10176 10177 10178 10179 10180 10181 10182 10183 10184 |
# File 'lib/aws-sdk-backup/types.rb', line 10176 class RestoreTestingSelectionForUpdate < Struct.new( :iam_role_arn, :protected_resource_arns, :protected_resource_conditions, :restore_metadata_overrides, :validation_window_hours) SENSITIVE = [:restore_metadata_overrides] include Aws::Structure end |
#validation_window_hours ⇒ Integer
This value represents the time, in hours, data is retained after a restore test so that optional validation can be completed.
Accepted value is an integer between 0 and 168 (the hourly equivalent of seven days).
10176 10177 10178 10179 10180 10181 10182 10183 10184 |
# File 'lib/aws-sdk-backup/types.rb', line 10176 class RestoreTestingSelectionForUpdate < Struct.new( :iam_role_arn, :protected_resource_arns, :protected_resource_conditions, :restore_metadata_overrides, :validation_window_hours) SENSITIVE = [:restore_metadata_overrides] include Aws::Structure end |