Class: Aws::Backup::Types::RevokeRestoreAccessBackupVaultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::RevokeRestoreAccessBackupVaultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:requester_comment]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of the source backup vault associated with the restore access backup vault to be revoked.
-
#requester_comment ⇒ String
A comment explaining the reason for revoking access to the restore access backup vault.
-
#restore_access_backup_vault_arn ⇒ String
The ARN of the restore access backup vault to revoke.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of the source backup vault associated with the restore access backup vault to be revoked.
9718 9719 9720 9721 9722 9723 9724 |
# File 'lib/aws-sdk-backup/types.rb', line 9718 class RevokeRestoreAccessBackupVaultInput < Struct.new( :backup_vault_name, :restore_access_backup_vault_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |
#requester_comment ⇒ String
A comment explaining the reason for revoking access to the restore access backup vault.
9718 9719 9720 9721 9722 9723 9724 |
# File 'lib/aws-sdk-backup/types.rb', line 9718 class RevokeRestoreAccessBackupVaultInput < Struct.new( :backup_vault_name, :restore_access_backup_vault_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |
#restore_access_backup_vault_arn ⇒ String
The ARN of the restore access backup vault to revoke.
9718 9719 9720 9721 9722 9723 9724 |
# File 'lib/aws-sdk-backup/types.rb', line 9718 class RevokeRestoreAccessBackupVaultInput < Struct.new( :backup_vault_name, :restore_access_backup_vault_arn, :requester_comment) SENSITIVE = [:requester_comment] include Aws::Structure end |