Class: Aws::Backup::Types::ScanJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ScanJob
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains metadata about a scan job, including information about the scanning process, results, and associated resources.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account ID that owns the scan job.
-
#backup_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup vault; for example, ‘arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault`.
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#completion_date ⇒ Time
The date and time that a scan job is completed, in Unix format and Coordinated Universal Time (UTC).
-
#continuous_scan_end_time ⇒ Time
The point in time the scan job scanned up to for a continuous backup.
-
#continuous_scan_start_time ⇒ Time
The point in time the scan job started scan from for a continuous backup.
-
#created_by ⇒ Types::ScanJobCreator
Contains identifying information about the creation of a scan job.
-
#creation_date ⇒ Time
The date and time that a scan job is created, in Unix format and Coordinated Universal Time (UTC).
-
#iam_role_arn ⇒ String
Specifies the IAM role ARN used to create the scan job; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
-
#malware_scanner ⇒ String
The scanning engine used for the scan job.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies the recovery point being scanned; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
-
#resource_arn ⇒ String
An ARN that uniquely identifies the source resource of the recovery point being scanned.
-
#resource_name ⇒ String
The non-unique name of the resource that belongs to the specified backup.
-
#resource_type ⇒ String
The type of Amazon Web Services resource being scanned; for example, an Amazon Elastic Block Store (Amazon EBS) volume or an Amazon Relational Database Service (Amazon RDS) database.
-
#scan_base_recovery_point_arn ⇒ String
An ARN that uniquely identifies the base recovery point for scanning.
-
#scan_id ⇒ String
The scan ID generated by the malware scanner for the corresponding scan job.
-
#scan_job_id ⇒ String
The unique identifier that identifies the scan job request to Backup.
-
#scan_mode ⇒ String
Specifies the scan type use for the scan job.
-
#scan_result ⇒ Types::ScanResultInfo
Contains the scan results information, including the status of threats found during scanning.
-
#scanner_role_arn ⇒ String
Specifies the scanner IAM role ARN used for the scan job.
-
#state ⇒ String
The current state of the scan job.
-
#status_message ⇒ String
A detailed message explaining the status of the scan job.
Instance Attribute Details
#account_id ⇒ String
The account ID that owns the scan job.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#backup_vault_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup vault; for example, ‘arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault`.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#completion_date ⇒ Time
The date and time that a scan job is completed, in Unix format and Coordinated Universal Time (UTC). The value of ‘CompletionDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#continuous_scan_end_time ⇒ Time
The point in time the scan job scanned up to for a continuous backup.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#continuous_scan_start_time ⇒ Time
The point in time the scan job started scan from for a continuous backup.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#created_by ⇒ Types::ScanJobCreator
Contains identifying information about the creation of a scan job.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a scan job is created, in Unix format and Coordinated Universal Time (UTC). The value of ‘CreationDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
Specifies the IAM role ARN used to create the scan job; for example, ‘arn:aws:iam::123456789012:role/S3Access`.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#malware_scanner ⇒ String
The scanning engine used for the scan job. Currently only ‘GUARDDUTY` is supported.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies the recovery point being scanned; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
An ARN that uniquely identifies the source resource of the recovery point being scanned.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_name ⇒ String
The non-unique name of the resource that belongs to the specified backup.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of Amazon Web Services resource being scanned; for example, an Amazon Elastic Block Store (Amazon EBS) volume or an Amazon Relational Database Service (Amazon RDS) database.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_base_recovery_point_arn ⇒ String
An ARN that uniquely identifies the base recovery point for scanning. This field is populated when an incremental scan job has taken place.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_id ⇒ String
The scan ID generated by the malware scanner for the corresponding scan job.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_job_id ⇒ String
The unique identifier that identifies the scan job request to Backup.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_mode ⇒ String
Specifies the scan type use for the scan job.
Includes:
‘FULL_SCAN` will scan the entire data lineage within the backup.
‘INCREMENTAL_SCAN` will scan the data difference between the target recovery point and base recovery point ARN.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scan_result ⇒ Types::ScanResultInfo
Contains the scan results information, including the status of threats found during scanning.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#scanner_role_arn ⇒ String
Specifies the scanner IAM role ARN used for the scan job.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The current state of the scan job.
Valid values: ‘CREATED` | `RUNNING` | `COMPLETED` | `COMPLETED_WITH_ISSUES` | `FAILED` | `CANCELED`.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |
#status_message ⇒ String
A detailed message explaining the status of the scan job.
9960 9961 9962 9963 9964 9965 9966 9967 9968 9969 9970 9971 9972 9973 9974 9975 9976 9977 9978 9979 9980 9981 9982 9983 9984 9985 |
# File 'lib/aws-sdk-backup/types.rb', line 9960 class ScanJob < Struct.new( :account_id, :backup_vault_arn, :backup_vault_name, :completion_date, :continuous_scan_end_time, :continuous_scan_start_time, :created_by, :creation_date, :iam_role_arn, :malware_scanner, :recovery_point_arn, :resource_arn, :resource_name, :resource_type, :scan_base_recovery_point_arn, :scan_id, :scan_job_id, :scan_mode, :scan_result, :scanner_role_arn, :state, :status_message) SENSITIVE = [] include Aws::Structure end |