Class: Aws::Backup::Types::ScheduledPlanExecutionMember
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ScheduledPlanExecutionMember
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Contains information about a scheduled backup plan execution, including the execution time, rule type, and associated rule identifier.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#execution_time ⇒ Time
The timestamp when the backup is scheduled to run, in Unix format and Coordinated Universal Time (UTC).
-
#rule_execution_type ⇒ String
The type of backup rule execution.
-
#rule_id ⇒ String
The unique identifier of the backup rule that will execute at the scheduled time.
Instance Attribute Details
#execution_time ⇒ Time
The timestamp when the backup is scheduled to run, in Unix format and Coordinated Universal Time (UTC). The value is accurate to milliseconds.
10593 10594 10595 10596 10597 10598 10599 |
# File 'lib/aws-sdk-backup/types.rb', line 10593 class ScheduledPlanExecutionMember < Struct.new( :execution_time, :rule_id, :rule_execution_type) SENSITIVE = [] include Aws::Structure end |
#rule_execution_type ⇒ String
The type of backup rule execution. Valid values are CONTINUOUS
(point-in-time recovery), SNAPSHOTS (snapshot backups), or
CONTINUOUS_AND_SNAPSHOTS (both types combined).
10593 10594 10595 10596 10597 10598 10599 |
# File 'lib/aws-sdk-backup/types.rb', line 10593 class ScheduledPlanExecutionMember < Struct.new( :execution_time, :rule_id, :rule_execution_type) SENSITIVE = [] include Aws::Structure end |
#rule_id ⇒ String
The unique identifier of the backup rule that will execute at the scheduled time.
10593 10594 10595 10596 10597 10598 10599 |
# File 'lib/aws-sdk-backup/types.rb', line 10593 class ScheduledPlanExecutionMember < Struct.new( :execution_time, :rule_id, :rule_execution_type) SENSITIVE = [] include Aws::Structure end |