Class: Aws::Backup::Types::StartBackupJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::StartBackupJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_job_id ⇒ String
Uniquely identifies a request to Backup to back up a resource.
-
#creation_date ⇒ Time
The date and time that a backup job is created, in Unix format and Coordinated Universal Time (UTC).
-
#is_parent ⇒ Boolean
This is a returned boolean value indicating this is a parent (composite) backup job.
-
#recovery_point_arn ⇒ String
Note: This field is only returned for Amazon EFS and Advanced DynamoDB resources..
Instance Attribute Details
#backup_job_id ⇒ String
Uniquely identifies a request to Backup to back up a resource.
10789 10790 10791 10792 10793 10794 10795 10796 |
# File 'lib/aws-sdk-backup/types.rb', line 10789 class StartBackupJobOutput < Struct.new( :backup_job_id, :recovery_point_arn, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a backup job is created, in Unix format and
Coordinated Universal Time (UTC). The value of CreationDate is
accurate to milliseconds. For example, the value 1516925490.087
represents Friday, January 26, 2018 12:11:30.087 AM.
10789 10790 10791 10792 10793 10794 10795 10796 |
# File 'lib/aws-sdk-backup/types.rb', line 10789 class StartBackupJobOutput < Struct.new( :backup_job_id, :recovery_point_arn, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |
#is_parent ⇒ Boolean
This is a returned boolean value indicating this is a parent (composite) backup job.
10789 10790 10791 10792 10793 10794 10795 10796 |
# File 'lib/aws-sdk-backup/types.rb', line 10789 class StartBackupJobOutput < Struct.new( :backup_job_id, :recovery_point_arn, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
Note: This field is only returned for Amazon EFS and Advanced DynamoDB resources.
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
10789 10790 10791 10792 10793 10794 10795 10796 |
# File 'lib/aws-sdk-backup/types.rb', line 10789 class StartBackupJobOutput < Struct.new( :backup_job_id, :recovery_point_arn, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |