Class: Aws::Backup::Types::StartRestoreJobInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:metadata]

Instance Attribute Summary collapse

Instance Attribute Details

#copy_source_tags_to_restored_resourceBoolean

This is an optional parameter. If this equals True, tags included in the backup will be copied to the restored resource.

This can only be applied to backups created through Backup.

Returns:

  • (Boolean)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end

#iam_role_arnString

The Amazon Resource Name (ARN) of the IAM role that Backup uses to create the target resource; for example: arn:aws:iam::123456789012:role/S3Access.

Returns:

  • (String)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end

#idempotency_tokenString

A customer-chosen string that you can use to distinguish between otherwise identical calls to StartRestoreJob. Retrying a successful request with the same idempotency token results in a success message with no action taken.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end

#metadataHash<String,String>

A set of metadata key-value pairs.

You can get configuration metadata about a resource at the time it was backed up by calling GetRecoveryPointRestoreMetadata. However, values in addition to those provided by GetRecoveryPointRestoreMetadata might be required to restore a resource. For example, you might need to provide a new resource name if the original already exists.

For more information about the metadata for each resource, see the following:

Returns:

  • (Hash<String,String>)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end

#recovery_point_arnString

An ARN that uniquely identifies a recovery point; for example, arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.

Returns:

  • (String)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end

#resource_typeString

Starts a job to restore a recovery point for one of the following resources:

  • Aurora - Amazon Aurora

  • DocumentDB - Amazon DocumentDB

  • CloudFormation - CloudFormation

  • DynamoDB - Amazon DynamoDB

  • EBS - Amazon Elastic Block Store

  • EC2 - Amazon Elastic Compute Cloud

  • EFS - Amazon Elastic File System

  • EKS - Amazon Elastic Kubernetes Service

  • FSx - Amazon FSx

  • Neptune - Amazon Neptune

  • RDS - Amazon Relational Database Service

  • Redshift - Amazon Redshift

  • Storage Gateway - Storage Gateway

  • S3 - Amazon Simple Storage Service

  • Timestream - Amazon Timestream

  • VirtualMachine - Virtual machines

Returns:

  • (String)


11063
11064
11065
11066
11067
11068
11069
11070
11071
11072
# File 'lib/aws-sdk-backup/types.rb', line 11063

class StartRestoreJobInput < Struct.new(
  :recovery_point_arn,
  :metadata,
  :iam_role_arn,
  :idempotency_token,
  :resource_type,
  :copy_source_tags_to_restored_resource)
  SENSITIVE = [:metadata]
  include Aws::Structure
end