Class: Aws::Backup::Types::StartScanJobInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Pattern: ‘^[a-zA-Z0-9-_]2,50$`

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#continuous_scan_end_timeTime

The point in time the scan job will scan up to for a continuous backup.

Returns:

  • (Time)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

Specifies the IAM role ARN used to create the target recovery point; for example, ‘arn:aws:iam::123456789012:role/S3Access`.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#idempotency_tokenString

A customer-chosen string that you can use to distinguish between otherwise identical calls to ‘StartScanJob`. Retrying a successful request with the same idempotency token results in a success message with no action taken.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#malware_scannerString

Specifies the malware scanner used during the scan job. Currently only supports ‘GUARDDUTY`.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

An Amazon Resource Name (ARN) that uniquely identifies a recovery point. This is your target recovery point for a full scan. If you are running an incremental scan, this will be your a recovery point which has been created after your base recovery point selection.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scan_base_recovery_point_arnString

An ARN that uniquely identifies the base recovery point to be used for incremental scanning.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scan_modeString

Specifies the scan type use for the scan job.

Includes:

  • ‘FULL_SCAN` will scan the entire data lineage within the backup.

  • ‘INCREMENTAL_SCAN` will scan the data difference between the target recovery point and base recovery point ARN.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end

#scanner_role_arnString

Specified the IAM scanner role ARN.

Returns:

  • (String)


10746
10747
10748
10749
10750
10751
10752
10753
10754
10755
10756
10757
10758
# File 'lib/aws-sdk-backup/types.rb', line 10746

class StartScanJobInput < Struct.new(
  :backup_vault_name,
  :continuous_scan_end_time,
  :iam_role_arn,
  :idempotency_token,
  :malware_scanner,
  :recovery_point_arn,
  :scan_base_recovery_point_arn,
  :scan_mode,
  :scanner_role_arn)
  SENSITIVE = []
  include Aws::Structure
end