Class: Aws::Backup::Types::UpdateBackupPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::UpdateBackupPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
Contains a list of
BackupOptionsfor each resource type. -
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example,
arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50. -
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
-
#creation_date ⇒ Time
The date and time a backup plan is created, in Unix format and Coordinated Universal Time (UTC).
-
#scan_settings ⇒ Array<Types::ScanSetting>
Contains your scanning configuration for the backup plan and includes the Malware scanner, your selected resources, and scanner role.
-
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long.
Instance Attribute Details
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
Contains a list of BackupOptions for each resource type.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup
plan; for example,
arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |
#backup_plan_id ⇒ String
Uniquely identifies a backup plan.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time a backup plan is created, in Unix format and
Coordinated Universal Time (UTC). The value of CreationDate is
accurate to milliseconds. For example, the value 1516925490.087
represents Friday, January 26, 2018 12:11:30.087 AM.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |
#scan_settings ⇒ Array<Types::ScanSetting>
Contains your scanning configuration for the backup plan and includes the Malware scanner, your selected resources, and scanner role.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. Version Ids cannot be edited.
11444 11445 11446 11447 11448 11449 11450 11451 11452 11453 |
# File 'lib/aws-sdk-backup/types.rb', line 11444 class UpdateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings, :scan_settings) SENSITIVE = [] include Aws::Structure end |