Class: Aws::Backup::Types::UpdateRecoveryPointIndexSettingsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.

Accepted characters include lowercase letters, numbers, and hyphens.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
# File 'lib/aws-sdk-backup/types.rb', line 11176

class UpdateRecoveryPointIndexSettingsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn,
  :iam_role_arn,
  :index)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

This specifies the IAM role ARN used for this operation.

For example, arn:aws:iam::123456789012:role/S3Access

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
# File 'lib/aws-sdk-backup/types.rb', line 11176

class UpdateRecoveryPointIndexSettingsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn,
  :iam_role_arn,
  :index)
  SENSITIVE = []
  include Aws::Structure
end

#indexString

Index can have 1 of 2 possible values, either ‘ENABLED` or `DISABLED`.

To create a backup index for an eligible ‘ACTIVE` recovery point that does not yet have a backup index, set value to `ENABLED`.

To delete a backup index, set value to ‘DISABLED`.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
# File 'lib/aws-sdk-backup/types.rb', line 11176

class UpdateRecoveryPointIndexSettingsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn,
  :iam_role_arn,
  :index)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.

Returns:

  • (String)


11176
11177
11178
11179
11180
11181
11182
11183
# File 'lib/aws-sdk-backup/types.rb', line 11176

class UpdateRecoveryPointIndexSettingsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn,
  :iam_role_arn,
  :index)
  SENSITIVE = []
  include Aws::Structure
end