Class: Aws::Backup::Types::UpdateRecoveryPointIndexSettingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::UpdateRecoveryPointIndexSettingsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#index ⇒ String
Index can have 1 of 2 possible values, either ‘ENABLED` or `DISABLED`.
-
#index_status ⇒ String
This is the current status for the backup index associated with the specified recovery point.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.
11118 11119 11120 11121 11122 11123 11124 11125 |
# File 'lib/aws-sdk-backup/types.rb', line 11118 class UpdateRecoveryPointIndexSettingsOutput < Struct.new( :backup_vault_name, :recovery_point_arn, :index_status, :index) SENSITIVE = [] include Aws::Structure end |
#index ⇒ String
Index can have 1 of 2 possible values, either ‘ENABLED` or `DISABLED`.
A value of ‘ENABLED` means a backup index for an eligible `ACTIVE` recovery point has been created.
A value of ‘DISABLED` means a backup index was deleted.
11118 11119 11120 11121 11122 11123 11124 11125 |
# File 'lib/aws-sdk-backup/types.rb', line 11118 class UpdateRecoveryPointIndexSettingsOutput < Struct.new( :backup_vault_name, :recovery_point_arn, :index_status, :index) SENSITIVE = [] include Aws::Structure end |
#index_status ⇒ String
This is the current status for the backup index associated with the specified recovery point.
Statuses are: ‘PENDING` | `ACTIVE` | `FAILED` | `DELETING`
A recovery point with an index that has the status of ‘ACTIVE` can be included in a search.
11118 11119 11120 11121 11122 11123 11124 11125 |
# File 'lib/aws-sdk-backup/types.rb', line 11118 class UpdateRecoveryPointIndexSettingsOutput < Struct.new( :backup_vault_name, :recovery_point_arn, :index_status, :index) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
11118 11119 11120 11121 11122 11123 11124 11125 |
# File 'lib/aws-sdk-backup/types.rb', line 11118 class UpdateRecoveryPointIndexSettingsOutput < Struct.new( :backup_vault_name, :recovery_point_arn, :index_status, :index) SENSITIVE = [] include Aws::Structure end |