Class: Aws::Backup::Types::UpdateRecoveryPointLifecycleOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_arnString

An ARN that uniquely identifies a backup vault; for example, ‘arn:aws:backup:us-east-1:123456789012:backup-vault:aBackupVault`.

Returns:

  • (String)


11300
11301
11302
11303
11304
11305
11306
11307
# File 'lib/aws-sdk-backup/types.rb', line 11300

class UpdateRecoveryPointLifecycleOutput < Struct.new(
  :backup_vault_arn,
  :recovery_point_arn,
  :lifecycle,
  :calculated_lifecycle)
  SENSITIVE = []
  include Aws::Structure
end

#calculated_lifecycleTypes::CalculatedLifecycle

A ‘CalculatedLifecycle` object containing `DeleteAt` and `MoveToColdStorageAt` timestamps.



11300
11301
11302
11303
11304
11305
11306
11307
# File 'lib/aws-sdk-backup/types.rb', line 11300

class UpdateRecoveryPointLifecycleOutput < Struct.new(
  :backup_vault_arn,
  :recovery_point_arn,
  :lifecycle,
  :calculated_lifecycle)
  SENSITIVE = []
  include Aws::Structure
end

#lifecycleTypes::Lifecycle

The lifecycle defines when a protected resource is transitioned to cold storage and when it expires. Backup transitions and expires backups automatically according to the lifecycle that you define.

Backups transitioned to cold storage must be stored in cold storage for a minimum of 90 days. Therefore, the “retention” setting must be 90 days greater than the “transition to cold after days” setting. The “transition to cold after days” setting cannot be changed after a backup has been transitioned to cold.

Resource types that can transition to cold storage are listed in the

Feature availability by resource][1

table. Backup ignores this

expression for other resource types.

[1]: docs.aws.amazon.com/aws-backup/latest/devguide/backup-feature-availability.html#features-by-resource

Returns:



11300
11301
11302
11303
11304
11305
11306
11307
# File 'lib/aws-sdk-backup/types.rb', line 11300

class UpdateRecoveryPointLifecycleOutput < Struct.new(
  :backup_vault_arn,
  :recovery_point_arn,
  :lifecycle,
  :calculated_lifecycle)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.

Returns:

  • (String)


11300
11301
11302
11303
11304
11305
11306
11307
# File 'lib/aws-sdk-backup/types.rb', line 11300

class UpdateRecoveryPointLifecycleOutput < Struct.new(
  :backup_vault_arn,
  :recovery_point_arn,
  :lifecycle,
  :calculated_lifecycle)
  SENSITIVE = []
  include Aws::Structure
end