Class: Aws::Backup::Types::UpdateReportPlanInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idempotency_tokenString

A customer-chosen string that you can use to distinguish between otherwise identical calls to ‘UpdateReportPlanInput`. Retrying a successful request with the same idempotency token results in a success message with no action taken.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


11385
11386
11387
11388
11389
11390
11391
11392
11393
# File 'lib/aws-sdk-backup/types.rb', line 11385

class UpdateReportPlanInput < Struct.new(
  :report_plan_name,
  :report_plan_description,
  :report_delivery_channel,
  :report_setting,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#report_delivery_channelTypes::ReportDeliveryChannel

The information about where to deliver your reports, specifically your Amazon S3 bucket name, S3 key prefix, and the formats of your reports.



11385
11386
11387
11388
11389
11390
11391
11392
11393
# File 'lib/aws-sdk-backup/types.rb', line 11385

class UpdateReportPlanInput < Struct.new(
  :report_plan_name,
  :report_plan_description,
  :report_delivery_channel,
  :report_setting,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#report_plan_descriptionString

An optional description of the report plan with a maximum 1,024 characters.

Returns:

  • (String)


11385
11386
11387
11388
11389
11390
11391
11392
11393
# File 'lib/aws-sdk-backup/types.rb', line 11385

class UpdateReportPlanInput < Struct.new(
  :report_plan_name,
  :report_plan_description,
  :report_delivery_channel,
  :report_setting,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#report_plan_nameString

The unique name of the report plan. This name is between 1 and 256 characters, starting with a letter, and consisting of letters (a-z, A-Z), numbers (0-9), and underscores (_).

Returns:

  • (String)


11385
11386
11387
11388
11389
11390
11391
11392
11393
# File 'lib/aws-sdk-backup/types.rb', line 11385

class UpdateReportPlanInput < Struct.new(
  :report_plan_name,
  :report_plan_description,
  :report_delivery_channel,
  :report_setting,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end

#report_settingTypes::ReportSetting

The report template for the report. Reports are built using a report template. The report templates are:

‘RESOURCE_COMPLIANCE_REPORT | CONTROL_COMPLIANCE_REPORT | BACKUP_JOB_REPORT | COPY_JOB_REPORT | RESTORE_JOB_REPORT`

If the report template is ‘RESOURCE_COMPLIANCE_REPORT` or `CONTROL_COMPLIANCE_REPORT`, this API resource also describes the report coverage by Amazon Web Services Regions and frameworks.



11385
11386
11387
11388
11389
11390
11391
11392
11393
# File 'lib/aws-sdk-backup/types.rb', line 11385

class UpdateReportPlanInput < Struct.new(
  :report_plan_name,
  :report_plan_description,
  :report_delivery_channel,
  :report_setting,
  :idempotency_token)
  SENSITIVE = []
  include Aws::Structure
end