Class: Aws::Backup::Types::UpdateReportPlanOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#creation_timeTime

The date and time that a report plan is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


11815
11816
11817
11818
11819
11820
11821
# File 'lib/aws-sdk-backup/types.rb', line 11815

class UpdateReportPlanOutput < Struct.new(
  :report_plan_name,
  :report_plan_arn,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#report_plan_arnString

An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.

Returns:

  • (String)


11815
11816
11817
11818
11819
11820
11821
# File 'lib/aws-sdk-backup/types.rb', line 11815

class UpdateReportPlanOutput < Struct.new(
  :report_plan_name,
  :report_plan_arn,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end

#report_plan_nameString

The unique name of the report plan.

Returns:

  • (String)


11815
11816
11817
11818
11819
11820
11821
# File 'lib/aws-sdk-backup/types.rb', line 11815

class UpdateReportPlanOutput < Struct.new(
  :report_plan_name,
  :report_plan_arn,
  :creation_time)
  SENSITIVE = []
  include Aws::Structure
end