Class: Aws::Backup::Types::UpdateRestoreTestingSelectionInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#restore_testing_plan_nameString

The restore testing plan name is required to update the indicated testing plan.

Returns:

  • (String)


11888
11889
11890
11891
11892
11893
11894
# File 'lib/aws-sdk-backup/types.rb', line 11888

class UpdateRestoreTestingSelectionInput < Struct.new(
  :restore_testing_plan_name,
  :restore_testing_selection,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end

#restore_testing_selectionTypes::RestoreTestingSelectionForUpdate

To update your restore testing selection, you can use either protected resource ARNs or conditions, but not both. That is, if your selection has ProtectedResourceArns, requesting an update with the parameter ProtectedResourceConditions will be unsuccessful.



11888
11889
11890
11891
11892
11893
11894
# File 'lib/aws-sdk-backup/types.rb', line 11888

class UpdateRestoreTestingSelectionInput < Struct.new(
  :restore_testing_plan_name,
  :restore_testing_selection,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end

#restore_testing_selection_nameString

The required restore testing selection name of the restore testing selection you wish to update.

Returns:

  • (String)


11888
11889
11890
11891
11892
11893
11894
# File 'lib/aws-sdk-backup/types.rb', line 11888

class UpdateRestoreTestingSelectionInput < Struct.new(
  :restore_testing_plan_name,
  :restore_testing_selection,
  :restore_testing_selection_name)
  SENSITIVE = []
  include Aws::Structure
end