Class: Aws::Backup::Types::UpdateTieringConfigurationOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::UpdateTieringConfigurationOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time a tiering configuration was created, in Unix format and Coordinated Universal Time (UTC).
-
#last_updated_time ⇒ Time
The date and time a tiering configuration was updated, in Unix format and Coordinated Universal Time (UTC).
-
#tiering_configuration_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies the updated tiering configuration.
-
#tiering_configuration_name ⇒ String
This unique string is the name of the tiering configuration.
Instance Attribute Details
#creation_time ⇒ Time
The date and time a tiering configuration was created, in Unix
format and Coordinated Universal Time (UTC). The value of
CreationTime is accurate to milliseconds. For example, the value
1516925490.087 represents Friday, January 26, 2018 12:11:30.087AM.
11970 11971 11972 11973 11974 11975 11976 11977 |
# File 'lib/aws-sdk-backup/types.rb', line 11970 class UpdateTieringConfigurationOutput < Struct.new( :tiering_configuration_arn, :tiering_configuration_name, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#last_updated_time ⇒ Time
The date and time a tiering configuration was updated, in Unix
format and Coordinated Universal Time (UTC). The value of
LastUpdatedTime is accurate to milliseconds. For example, the
value 1516925490.087 represents Friday, January 26, 2018
12:11:30.087AM.
11970 11971 11972 11973 11974 11975 11976 11977 |
# File 'lib/aws-sdk-backup/types.rb', line 11970 class UpdateTieringConfigurationOutput < Struct.new( :tiering_configuration_arn, :tiering_configuration_name, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#tiering_configuration_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies the updated tiering configuration.
11970 11971 11972 11973 11974 11975 11976 11977 |
# File 'lib/aws-sdk-backup/types.rb', line 11970 class UpdateTieringConfigurationOutput < Struct.new( :tiering_configuration_arn, :tiering_configuration_name, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |
#tiering_configuration_name ⇒ String
This unique string is the name of the tiering configuration.
11970 11971 11972 11973 11974 11975 11976 11977 |
# File 'lib/aws-sdk-backup/types.rb', line 11970 class UpdateTieringConfigurationOutput < Struct.new( :tiering_configuration_arn, :tiering_configuration_name, :creation_time, :last_updated_time) SENSITIVE = [] include Aws::Structure end |