Class: Aws::Backup::Types::Conditions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Contains information about which resources to include or exclude from a backup plan using their tags. Conditions are case sensitive.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#string_equalsArray<Types::ConditionParameter>

Filters the values of your tagged resources for only those resources that you tagged with the same value. Also called “exact matching.”



1161
1162
1163
1164
1165
1166
1167
1168
# File 'lib/aws-sdk-backup/types.rb', line 1161

class Conditions < Struct.new(
  :string_equals,
  :string_not_equals,
  :string_like,
  :string_not_like)
  SENSITIVE = []
  include Aws::Structure
end

#string_likeArray<Types::ConditionParameter>

Filters the values of your tagged resources for matching tag values with the use of a wildcard character (*) anywhere in the string. For example, “prod*” or “rod” matches the tag value “production”.



1161
1162
1163
1164
1165
1166
1167
1168
# File 'lib/aws-sdk-backup/types.rb', line 1161

class Conditions < Struct.new(
  :string_equals,
  :string_not_equals,
  :string_like,
  :string_not_like)
  SENSITIVE = []
  include Aws::Structure
end

#string_not_equalsArray<Types::ConditionParameter>

Filters the values of your tagged resources for only those resources that you tagged that do not have the same value. Also called “negated matching.”



1161
1162
1163
1164
1165
1166
1167
1168
# File 'lib/aws-sdk-backup/types.rb', line 1161

class Conditions < Struct.new(
  :string_equals,
  :string_not_equals,
  :string_like,
  :string_not_like)
  SENSITIVE = []
  include Aws::Structure
end

#string_not_likeArray<Types::ConditionParameter>

Filters the values of your tagged resources for non-matching tag values with the use of a wildcard character (*) anywhere in the string.



1161
1162
1163
1164
1165
1166
1167
1168
# File 'lib/aws-sdk-backup/types.rb', line 1161

class Conditions < Struct.new(
  :string_equals,
  :string_not_equals,
  :string_like,
  :string_not_like)
  SENSITIVE = []
  include Aws::Structure
end