Class: Aws::Backup::Types::CreateBackupAccessPointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::CreateBackupAccessPointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:access_point_metadata, :tags]
Instance Attribute Summary collapse
-
#access_point_metadata ⇒ Hash<String,String>
Metadata for the backup access point.
-
#access_point_policy ⇒ String
An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point.
-
#name ⇒ String
The name of the backup access point.
-
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point for which to create the backup access point.
-
#tags ⇒ Hash<String,String>
The tags to assign to the backup access point.
Instance Attribute Details
#access_point_metadata ⇒ Hash<String,String>
Metadata for the backup access point. For continuous (point-in-time)
recovery points, you must include an AccessPointInTime timestamp
(in format 2021-11-27T03:30:27Z). The access point provides access
to the content present in the backup at that specific time. You can
specify any time within the continuous backup's retention period,
up to the latest restorable time. For snapshot recovery points, do
not include AccessPointInTime.
1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-backup/types.rb', line 1886 class CreateBackupAccessPointRequest < Struct.new( :access_point_metadata, :access_point_policy, :name, :recovery_point_arn, :tags) SENSITIVE = [:access_point_metadata, :tags] include Aws::Structure end |
#access_point_policy ⇒ String
An optional resource-based policy, in JSON format, to apply to the underlying Amazon S3 access point. The policy controls how backup data can be accessed through the access point. If you do not specify a policy, access is governed by the caller's IAM permissions. For more information, see Configuring IAM policies for using access points in the Amazon S3 User Guide.
1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-backup/types.rb', line 1886 class CreateBackupAccessPointRequest < Struct.new( :access_point_metadata, :access_point_policy, :name, :recovery_point_arn, :tags) SENSITIVE = [:access_point_metadata, :tags] include Aws::Structure end |
#name ⇒ String
The name of the backup access point. This name is shared with the Amazon S3 access point namespace. It must be unique within your account and Region and cannot conflict with an existing Amazon S3 access point. For more information about access point naming, see Access points naming rules, restrictions, and limitations in the Amazon S3 User Guide.
1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-backup/types.rb', line 1886 class CreateBackupAccessPointRequest < Struct.new( :access_point_metadata, :access_point_policy, :name, :recovery_point_arn, :tags) SENSITIVE = [:access_point_metadata, :tags] include Aws::Structure end |
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point for which to
create the backup access point. The recovery point must be an Amazon
S3 recovery point in the AVAILABLE, STOPPED, or COMPLETED
state.
1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-backup/types.rb', line 1886 class CreateBackupAccessPointRequest < Struct.new( :access_point_metadata, :access_point_policy, :name, :recovery_point_arn, :tags) SENSITIVE = [:access_point_metadata, :tags] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The tags to assign to the backup access point.
1886 1887 1888 1889 1890 1891 1892 1893 1894 |
# File 'lib/aws-sdk-backup/types.rb', line 1886 class CreateBackupAccessPointRequest < Struct.new( :access_point_metadata, :access_point_policy, :name, :recovery_point_arn, :tags) SENSITIVE = [:access_point_metadata, :tags] include Aws::Structure end |