Class: Aws::Backup::Types::CreateBackupPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::CreateBackupPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
The settings for a resource type.
-
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup plan; for example,
arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50. -
#backup_plan_id ⇒ String
The ID of the backup plan.
-
#creation_date ⇒ Time
The date and time that a backup plan is created, in Unix format and Coordinated Universal Time (UTC).
-
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long.
Instance Attribute Details
#advanced_backup_settings ⇒ Array<Types::AdvancedBackupSetting>
The settings for a resource type. This option is only available for Windows Volume Shadow Copy Service (VSS) backup jobs.
1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-backup/types.rb', line 1977 class CreateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings) SENSITIVE = [] include Aws::Structure end |
#backup_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a backup
plan; for example,
arn:aws:backup:us-east-1:123456789012:plan:8F81F553-3A74-4A3F-B93D-B3360DC80C50.
1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-backup/types.rb', line 1977 class CreateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings) SENSITIVE = [] include Aws::Structure end |
#backup_plan_id ⇒ String
The ID of the backup plan.
1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-backup/types.rb', line 1977 class CreateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a backup plan is created, in Unix format and
Coordinated Universal Time (UTC). The value of CreationDate is
accurate to milliseconds. For example, the value 1516925490.087
represents Friday, January 26, 2018 12:11:30.087 AM.
1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-backup/types.rb', line 1977 class CreateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings) SENSITIVE = [] include Aws::Structure end |
#version_id ⇒ String
Unique, randomly generated, Unicode, UTF-8 encoded strings that are at most 1,024 bytes long. They cannot be edited.
1977 1978 1979 1980 1981 1982 1983 1984 1985 |
# File 'lib/aws-sdk-backup/types.rb', line 1977 class CreateBackupPlanOutput < Struct.new( :backup_plan_id, :backup_plan_arn, :creation_date, :version_id, :advanced_backup_settings) SENSITIVE = [] include Aws::Structure end |