Class: Aws::Backup::Types::CreateBackupSelectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::CreateBackupSelectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_plan_id ⇒ String
The ID of the backup plan.
-
#backup_selection ⇒ Types::BackupSelection
The body of a request to assign a set of resources to a backup plan.
-
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice.
Instance Attribute Details
#backup_plan_id ⇒ String
The ID of the backup plan.
2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-backup/types.rb', line 2009 class CreateBackupSelectionInput < Struct.new( :backup_plan_id, :backup_selection, :creator_request_id) SENSITIVE = [] include Aws::Structure end |
#backup_selection ⇒ Types::BackupSelection
The body of a request to assign a set of resources to a backup plan.
2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-backup/types.rb', line 2009 class CreateBackupSelectionInput < Struct.new( :backup_plan_id, :backup_selection, :creator_request_id) SENSITIVE = [] include Aws::Structure end |
#creator_request_id ⇒ String
A unique string that identifies the request and allows failed requests to be retried without the risk of running the operation twice. This parameter is optional.
If used, this parameter must contain 1 to 50 alphanumeric or '-_.' characters.
A suitable default value is auto-generated. You should normally not need to pass this option.
2009 2010 2011 2012 2013 2014 2015 |
# File 'lib/aws-sdk-backup/types.rb', line 2009 class CreateBackupSelectionInput < Struct.new( :backup_plan_id, :backup_selection, :creator_request_id) SENSITIVE = [] include Aws::Structure end |