Method: Aws::Backup::Types::DeleteBackupSelectionInput#selection_id
- Defined in:
- lib/aws-sdk-backup/types.rb
#selection_id ⇒ String
Uniquely identifies the body of a request to assign a set of resources to a backup plan.
2255 2256 2257 2258 2259 2260 |
# File 'lib/aws-sdk-backup/types.rb', line 2255 class DeleteBackupSelectionInput < Struct.new( :backup_plan_id, :selection_id) SENSITIVE = [] include Aws::Structure end |