Class: Aws::Backup::Types::DescribeBackupAccessPointResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeBackupAccessPointResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:access_point_metadata]
Instance Attribute Summary collapse
-
#access_point_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the backup access point.
-
#access_point_metadata ⇒ Hash<String,String>
Metadata for the backup access point.
-
#backup_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the backup vault that contains the recovery point.
-
#backup_vault_name ⇒ String
The name of the backup vault that contains the recovery point.
-
#creation_time ⇒ Time
The date and time that the backup access point was created, in Unix format and Coordinated Universal Time (UTC).
-
#name ⇒ String
The name of the backup access point.
-
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point that the backup access point provides access to.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that was backed up, such as an Amazon S3 bucket.
-
#resource_type ⇒ String
The type of Amazon Web Services resource associated with the recovery point.
-
#status ⇒ String
The current status of the backup access point.
-
#status_message ⇒ String
A message that provides additional detail about the status of the backup access point, such as the reason a creation or deletion attempt failed.
Instance Attribute Details
#access_point_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the backup access point.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#access_point_metadata ⇒ Hash<String,String>
Metadata for the backup access point. After the backup access point
reaches the AVAILABLE status, this map contains S3AccessPointArn
and S3AccessPointAlias, which you use with standard Amazon S3 read
APIs to access the backup data. For continuous recovery points, this
map also contains AccessPointInTime (in format
2021-11-27T03:30:27Z). The access point provides access to the
content present in the backup at that specific time.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#backup_vault_arn ⇒ String
The Amazon Resource Name (ARN) of the backup vault that contains the recovery point.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of the backup vault that contains the recovery point.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#creation_time ⇒ Time
The date and time that the backup access point was created, in Unix
format and Coordinated Universal Time (UTC). The value of
CreationTime is accurate to milliseconds. For example, the value
1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#name ⇒ String
The name of the backup access point.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point that the backup access point provides access to.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource that was backed up, such as an Amazon S3 bucket.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#resource_type ⇒ String
The type of Amazon Web Services resource associated with the
recovery point. For example, S3 for Amazon Simple Storage Service.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#status ⇒ String
The current status of the backup access point.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |
#status_message ⇒ String
A message that provides additional detail about the status of the backup access point, such as the reason a creation or deletion attempt failed.
3054 3055 3056 3057 3058 3059 3060 3061 3062 3063 3064 3065 3066 3067 3068 |
# File 'lib/aws-sdk-backup/types.rb', line 3054 class DescribeBackupAccessPointResponse < Struct.new( :access_point_arn, :access_point_metadata, :backup_vault_arn, :backup_vault_name, :creation_time, :name, :recovery_point_arn, :resource_arn, :resource_type, :status, :status_message) SENSITIVE = [:access_point_metadata] include Aws::Structure end |