Class: Aws::Backup::Types::DescribeBackupVaultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeBackupVaultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
Instance Attribute Details
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
3370 3371 3372 3373 3374 3375 |
# File 'lib/aws-sdk-backup/types.rb', line 3370 class DescribeBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
3370 3371 3372 3373 3374 3375 |
# File 'lib/aws-sdk-backup/types.rb', line 3370 class DescribeBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id) SENSITIVE = [] include Aws::Structure end |