Class: Aws::Backup::Types::DescribeGlobalSettingsOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DescribeGlobalSettingsOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_settings ⇒ Hash<String,String>
The status of the flags ‘isCrossAccountBackupEnabled`, `isMpaEnabled` (’Mpa’ refers to multi-party approval), and ‘isDelegatedAdministratorEnabled`.
-
#last_update_time ⇒ Time
The date and time that the supported flags were last updated.
Instance Attribute Details
#global_settings ⇒ Hash<String,String>
The status of the flags ‘isCrossAccountBackupEnabled`, `isMpaEnabled` (’Mpa’ refers to multi-party approval), and ‘isDelegatedAdministratorEnabled`.
-
‘isCrossAccountBackupEnabled`: Allow accounts in your organization to copy backups to other accounts.
-
‘isMpaEnabled`: Add cross-account access to your organization with the option to assign a Multi-party approval team to a logically air-gapped vault.
-
‘isDelegatedAdministratorEnabled`: Allow Backup to automatically synchronize delegated administrator permissions with Organizations.
3486 3487 3488 3489 3490 3491 |
# File 'lib/aws-sdk-backup/types.rb', line 3486 class DescribeGlobalSettingsOutput < Struct.new( :global_settings, :last_update_time) SENSITIVE = [] include Aws::Structure end |
#last_update_time ⇒ Time
The date and time that the supported flags were last updated. This update is in Unix format and Coordinated Universal Time (UTC). The value of ‘LastUpdateTime` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
3486 3487 3488 3489 3490 3491 |
# File 'lib/aws-sdk-backup/types.rb', line 3486 class DescribeGlobalSettingsOutput < Struct.new( :global_settings, :last_update_time) SENSITIVE = [] include Aws::Structure end |