Class: Aws::Backup::Types::DescribeReportPlanOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#report_planTypes::ReportPlan

Returns details about the report plan that is specified by its name. These details include the report plan’s Amazon Resource Name (ARN), description, settings, delivery channel, deployment status, creation time, and last attempted and successful run times.

Returns:



3950
3951
3952
3953
3954
# File 'lib/aws-sdk-backup/types.rb', line 3950

class DescribeReportPlanOutput < Struct.new(
  :report_plan)
  SENSITIVE = []
  include Aws::Structure
end