Class: Aws::Backup::Types::DisassociateRecoveryPointFromParentInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::DisassociateRecoveryPointFromParentInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where the child (nested) recovery point is stored.
-
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the child (nested) recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.`.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where the child (nested) recovery point is stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
4310 4311 4312 4313 4314 4315 |
# File 'lib/aws-sdk-backup/types.rb', line 4310 class DisassociateRecoveryPointFromParentInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) that uniquely identifies the child (nested) recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.`
4310 4311 4312 4313 4314 4315 |
# File 'lib/aws-sdk-backup/types.rb', line 4310 class DisassociateRecoveryPointFromParentInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |