Class: Aws::Backup::Types::GetBackupVaultAccessPolicyInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetBackupVaultAccessPolicyInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
4667 4668 4669 4670 4671 |
# File 'lib/aws-sdk-backup/types.rb', line 4667 class GetBackupVaultAccessPolicyInput < Struct.new( :backup_vault_name) SENSITIVE = [] include Aws::Structure end |