Class: Aws::Backup::Types::GetPITRMalwareScanResultsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.

Returns:

  • (String)


4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-backup/types.rb', line 4844

class GetPITRMalwareScanResultsInput < Struct.new(
  :recovery_point_arn,
  :backup_vault_name,
  :scan_end_time,
  :malware_scanner)
  SENSITIVE = []
  include Aws::Structure
end

#malware_scannerString

The scanning engine used for the corresponding scan job. Currently only ‘GUARDDUTY` is supported.

Returns:

  • (String)


4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-backup/types.rb', line 4844

class GetPITRMalwareScanResultsInput < Struct.new(
  :recovery_point_arn,
  :backup_vault_name,
  :scan_end_time,
  :malware_scanner)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

An ARN that uniquely identifies the target recovery point for scanning; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.

Returns:

  • (String)


4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-backup/types.rb', line 4844

class GetPITRMalwareScanResultsInput < Struct.new(
  :recovery_point_arn,
  :backup_vault_name,
  :scan_end_time,
  :malware_scanner)
  SENSITIVE = []
  include Aws::Structure
end

#scan_end_timeTime

The point in time within the continuous backup to examine for malware scan results.

Returns:

  • (Time)


4844
4845
4846
4847
4848
4849
4850
4851
# File 'lib/aws-sdk-backup/types.rb', line 4844

class GetPITRMalwareScanResultsInput < Struct.new(
  :recovery_point_arn,
  :backup_vault_name,
  :scan_end_time,
  :malware_scanner)
  SENSITIVE = []
  include Aws::Structure
end