Class: Aws::Backup::Types::GetPITRMalwareScanResultsOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#last_scan_job_timeTime

The completion time of the most recent scan job that covered the specified point in time.

Returns:

  • (Time)


4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-backup/types.rb', line 4879

class GetPITRMalwareScanResultsOutput < Struct.new(
  :scan_end_time,
  :scan_result,
  :last_scan_job_time,
  :scan_id,
  :scan_mode)
  SENSITIVE = []
  include Aws::Structure
end

#scan_end_timeTime

The point in time that was queried. This echoes back the time specified in the request.

Returns:

  • (Time)


4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-backup/types.rb', line 4879

class GetPITRMalwareScanResultsOutput < Struct.new(
  :scan_end_time,
  :scan_result,
  :last_scan_job_time,
  :scan_id,
  :scan_mode)
  SENSITIVE = []
  include Aws::Structure
end

#scan_idString

The scan ID generated by Amazon GuardDuty for the corresponding Scan Job ID request from Backup.

Returns:

  • (String)


4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-backup/types.rb', line 4879

class GetPITRMalwareScanResultsOutput < Struct.new(
  :scan_end_time,
  :scan_result,
  :last_scan_job_time,
  :scan_id,
  :scan_mode)
  SENSITIVE = []
  include Aws::Structure
end

#scan_modeString

Specifies the scan type used for the scan job.

Returns:

  • (String)


4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-backup/types.rb', line 4879

class GetPITRMalwareScanResultsOutput < Struct.new(
  :scan_end_time,
  :scan_result,
  :last_scan_job_time,
  :scan_id,
  :scan_mode)
  SENSITIVE = []
  include Aws::Structure
end

#scan_resultTypes::ScanResultInfo

Contains the ‘ScanResultStatus` for the scan and returns `THREATS_FOUND`, `NO_THREATS_FOUND`, or `UNKNOWN`.



4879
4880
4881
4882
4883
4884
4885
4886
4887
# File 'lib/aws-sdk-backup/types.rb', line 4879

class GetPITRMalwareScanResultsOutput < Struct.new(
  :scan_end_time,
  :scan_result,
  :last_scan_job_time,
  :scan_id,
  :scan_mode)
  SENSITIVE = []
  include Aws::Structure
end