Class: Aws::Backup::Types::GetRecoveryPointIndexDetailsInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetRecoveryPointIndexDetailsInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.
Accepted characters include lowercase letters, numbers, and hyphens.
5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-backup/types.rb', line 5088 class GetRecoveryPointIndexDetailsInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An ARN that uniquely identifies a recovery point; for example,
arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45.
5088 5089 5090 5091 5092 5093 |
# File 'lib/aws-sdk-backup/types.rb', line 5088 class GetRecoveryPointIndexDetailsInput < Struct.new( :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |