Class: Aws::Backup::Types::GetRecoveryPointIndexDetailsInput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#backup_vault_nameString

The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Region where they are created.

Accepted characters include lowercase letters, numbers, and hyphens.

Returns:

  • (String)


4904
4905
4906
4907
4908
4909
# File 'lib/aws-sdk-backup/types.rb', line 4904

class GetRecoveryPointIndexDetailsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end

#recovery_point_arnString

An ARN that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.

Returns:

  • (String)


4904
4905
4906
4907
4908
4909
# File 'lib/aws-sdk-backup/types.rb', line 4904

class GetRecoveryPointIndexDetailsInput < Struct.new(
  :backup_vault_name,
  :recovery_point_arn)
  SENSITIVE = []
  include Aws::Structure
end