Class: Aws::Backup::Types::GetRecoveryPointRestoreMetadataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetRecoveryPointRestoreMetadataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
Instance Attribute Details
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
5005 5006 5007 5008 5009 5010 5011 |
# File 'lib/aws-sdk-backup/types.rb', line 5005 class GetRecoveryPointRestoreMetadataInput < Struct.new( :backup_vault_name, :recovery_point_arn, :backup_vault_account_id) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
5005 5006 5007 5008 5009 5010 5011 |
# File 'lib/aws-sdk-backup/types.rb', line 5005 class GetRecoveryPointRestoreMetadataInput < Struct.new( :backup_vault_name, :recovery_point_arn, :backup_vault_account_id) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
5005 5006 5007 5008 5009 5010 5011 |
# File 'lib/aws-sdk-backup/types.rb', line 5005 class GetRecoveryPointRestoreMetadataInput < Struct.new( :backup_vault_name, :recovery_point_arn, :backup_vault_account_id) SENSITIVE = [] include Aws::Structure end |