Class: Aws::Backup::Types::GetRestoreTestingInferredMetadataInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::GetRestoreTestingInferredMetadataInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
Instance Attribute Details
#backup_vault_account_id ⇒ String
The account ID of the specified backup vault.
5092 5093 5094 5095 5096 5097 5098 |
# File 'lib/aws-sdk-backup/types.rb', line 5092 class GetRestoreTestingInferredMetadataInput < Struct.new( :backup_vault_account_id, :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web ServicesRegion where they are created. They consist of letters, numbers, and hyphens.
5092 5093 5094 5095 5096 5097 5098 |
# File 'lib/aws-sdk-backup/types.rb', line 5092 class GetRestoreTestingInferredMetadataInput < Struct.new( :backup_vault_account_id, :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a recovery point; for example, ‘arn:aws:backup:us-east-1:123456789012:recovery-point:1EB3B5E7-9EB0-435A-A80B-108B488B0D45`.
5092 5093 5094 5095 5096 5097 5098 |
# File 'lib/aws-sdk-backup/types.rb', line 5092 class GetRestoreTestingInferredMetadataInput < Struct.new( :backup_vault_account_id, :backup_vault_name, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |