Class: Aws::Backup::Types::ListBackupAccessPointsByRecoveryPointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupAccessPointsByRecoveryPointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point whose backup access points you want to list.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of items to be returned.
5936 5937 5938 5939 5940 5941 5942 |
# File 'lib/aws-sdk-backup/types.rb', line 5936 class ListBackupAccessPointsByRecoveryPointRequest < Struct.new( :max_results, :next_token, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
5936 5937 5938 5939 5940 5941 5942 |
# File 'lib/aws-sdk-backup/types.rb', line 5936 class ListBackupAccessPointsByRecoveryPointRequest < Struct.new( :max_results, :next_token, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point whose backup access points you want to list.
5936 5937 5938 5939 5940 5941 5942 |
# File 'lib/aws-sdk-backup/types.rb', line 5936 class ListBackupAccessPointsByRecoveryPointRequest < Struct.new( :max_results, :next_token, :recovery_point_arn) SENSITIVE = [] include Aws::Structure end |