Class: Aws::Backup::Types::ListBackupPlansOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListBackupPlansOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_plans_list ⇒ Array<Types::BackupPlansListMember>
Information about the backup plans.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#backup_plans_list ⇒ Array<Types::BackupPlansListMember>
Information about the backup plans.
5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-backup/types.rb', line 5978 class ListBackupPlansOutput < Struct.new( :next_token, :backup_plans_list) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
5978 5979 5980 5981 5982 5983 |
# File 'lib/aws-sdk-backup/types.rb', line 5978 class ListBackupPlansOutput < Struct.new( :next_token, :backup_plans_list) SENSITIVE = [] include Aws::Structure end |