Class: Aws::Backup::Types::ListRecoveryPointsByBackupVaultInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListRecoveryPointsByBackupVaultInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_account_id ⇒ String
This parameter will sort the list of recovery points by account ID.
-
#backup_vault_name ⇒ String
The name of a logical container where backups are stored.
-
#by_backup_plan_id ⇒ String
Returns only recovery points that match the specified backup plan ID.
-
#by_created_after ⇒ Time
Returns only recovery points that were created after the specified timestamp.
-
#by_created_before ⇒ Time
Returns only recovery points that were created before the specified timestamp.
-
#by_parent_recovery_point_arn ⇒ String
This returns only recovery points that match the specified parent (composite) recovery point Amazon Resource Name (ARN).
-
#by_resource_arn ⇒ String
Returns only recovery points that match the specified resource Amazon Resource Name (ARN).
-
#by_resource_type ⇒ String
Returns only recovery points that match the specified resource type(s):.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
Instance Attribute Details
#backup_vault_account_id ⇒ String
This parameter will sort the list of recovery points by account ID.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#backup_vault_name ⇒ String
The name of a logical container where backups are stored. Backup vaults are identified by names that are unique to the account used to create them and the Amazon Web Services Region where they are created.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_backup_plan_id ⇒ String
Returns only recovery points that match the specified backup plan ID.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_created_after ⇒ Time
Returns only recovery points that were created after the specified timestamp.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_created_before ⇒ Time
Returns only recovery points that were created before the specified timestamp.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_parent_recovery_point_arn ⇒ String
This returns only recovery points that match the specified parent (composite) recovery point Amazon Resource Name (ARN).
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_resource_arn ⇒ String
Returns only recovery points that match the specified resource Amazon Resource Name (ARN).
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#by_resource_type ⇒ String
Returns only recovery points that match the specified resource type(s):
-
Aurorafor Amazon Aurora -
CloudFormationfor CloudFormation -
DocumentDBfor Amazon DocumentDB (with MongoDB compatibility) -
DynamoDBfor Amazon DynamoDB -
EBSfor Amazon Elastic Block Store -
EC2for Amazon Elastic Compute Cloud -
EFSfor Amazon Elastic File System -
EKSfor Amazon Elastic Kubernetes Service -
FSxfor Amazon FSx -
Neptunefor Amazon Neptune -
RDSfor Amazon Relational Database Service -
Redshiftfor Amazon Redshift -
S3for Amazon Simple Storage Service (Amazon S3) -
SAP HANA on Amazon EC2for SAP HANA databases on Amazon Elastic Compute Cloud instances -
Storage Gatewayfor Storage Gateway -
Timestreamfor Amazon Timestream -
VirtualMachinefor VMware virtual machines
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7231 7232 7233 7234 7235 7236 7237 7238 7239 7240 7241 7242 7243 7244 |
# File 'lib/aws-sdk-backup/types.rb', line 7231 class ListRecoveryPointsByBackupVaultInput < Struct.new( :backup_vault_name, :backup_vault_account_id, :next_token, :max_results, :by_resource_arn, :by_resource_type, :by_backup_plan_id, :by_created_before, :by_created_after, :by_parent_recovery_point_arn) SENSITIVE = [] include Aws::Structure end |