Class: Aws::Backup::Types::ListRecoveryPointsByBackupVaultOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListRecoveryPointsByBackupVaultOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#recovery_points ⇒ Array<Types::RecoveryPointByBackupVault>
An array of objects that contain detailed information about recovery points saved in a backup vault.
Instance Attribute Details
#next_token ⇒ String
The next item following a partial list of returned items. For example, if a request is made to return MaxResults number of items, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-backup/types.rb', line 6747 class ListRecoveryPointsByBackupVaultOutput < Struct.new( :next_token, :recovery_points) SENSITIVE = [] include Aws::Structure end |
#recovery_points ⇒ Array<Types::RecoveryPointByBackupVault>
An array of objects that contain detailed information about recovery points saved in a backup vault.
6747 6748 6749 6750 6751 6752 |
# File 'lib/aws-sdk-backup/types.rb', line 6747 class ListRecoveryPointsByBackupVaultOutput < Struct.new( :next_token, :recovery_points) SENSITIVE = [] include Aws::Structure end |