Class: Aws::Backup::Types::ListRecoveryPointsByLegalHoldInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListRecoveryPointsByLegalHoldInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#legal_hold_id ⇒ String
The ID of the legal hold.
-
#max_results ⇒ Integer
The maximum number of resource list items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned resources.
Instance Attribute Details
#legal_hold_id ⇒ String
The ID of the legal hold.
6771 6772 6773 6774 6775 6776 6777 |
# File 'lib/aws-sdk-backup/types.rb', line 6771 class ListRecoveryPointsByLegalHoldInput < Struct.new( :legal_hold_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of resource list items to be returned.
6771 6772 6773 6774 6775 6776 6777 |
# File 'lib/aws-sdk-backup/types.rb', line 6771 class ListRecoveryPointsByLegalHoldInput < Struct.new( :legal_hold_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned resources. For example, if a request is made to return MaxResults number of resources, NextToken allows you to return more items in your list starting at the location pointed to by the next token.
6771 6772 6773 6774 6775 6776 6777 |
# File 'lib/aws-sdk-backup/types.rb', line 6771 class ListRecoveryPointsByLegalHoldInput < Struct.new( :legal_hold_id, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |