Class: Aws::Backup::Types::ListScanJobSummariesInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::ListScanJobSummariesInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#account_id ⇒ String
Returns the job count for the specified account.
-
#aggregation_period ⇒ String
The period for the returned results.
-
#malware_scanner ⇒ String
Returns only the scan jobs for the specified malware scanner.
-
#max_results ⇒ Integer
The maximum number of items to be returned.
-
#next_token ⇒ String
The next item following a partial list of returned items.
-
#resource_type ⇒ String
Returns the job count for the specified resource type.
-
#scan_result_status ⇒ String
Returns only the scan jobs for the specified scan results.
-
#state ⇒ String
Returns only the scan jobs for the specified scanning job state.
Instance Attribute Details
#account_id ⇒ String
Returns the job count for the specified account.
If the request is sent from a member account or an account not part of Amazon Web Services Organizations, jobs within requestor's account will be returned.
Root, admin, and delegated administrator accounts can use the value
ANY to return job counts from every account in the organization.
AGGREGATE_ALL aggregates job counts from all accounts within the
authenticated organization, then returns the sum.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#aggregation_period ⇒ String
The period for the returned results.
-
ONE_DAYThe daily job count for the prior 1 day. -
SEVEN_DAYSThe daily job count for the prior 7 days. -
FOURTEEN_DAYSThe daily job count for the prior 14 days.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#malware_scanner ⇒ String
Returns only the scan jobs for the specified malware scanner.
Currently the only MalwareScanner is GUARDDUTY. But the field also
supports ANY, and AGGREGATE_ALL.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of items to be returned.
The value is an integer. Range of accepted values is from 1 to 500.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
The next item following a partial list of returned items. For
example, if a request is made to return MaxResults number of
items, NextToken allows you to return more items in your list
starting at the location pointed to by the next token.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
Returns the job count for the specified resource type. Use request
GetSupportedResourceTypes to obtain strings for supported resource
types.
The the value ANY returns count of all resource types.
AGGREGATE_ALL aggregates job counts for all resource types and
returns the sum.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#scan_result_status ⇒ String
Returns only the scan jobs for the specified scan results.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
Returns only the scan jobs for the specified scanning job state.
7989 7990 7991 7992 7993 7994 7995 7996 7997 7998 7999 8000 |
# File 'lib/aws-sdk-backup/types.rb', line 7989 class ListScanJobSummariesInput < Struct.new( :account_id, :resource_type, :malware_scanner, :scan_result_status, :state, :aggregation_period, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |