Class: Aws::Backup::Types::ReportJob

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-backup/types.rb

Overview

Contains detailed information about a report job. A report job compiles a report based on a report plan and publishes it to Amazon S3.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#completion_timeTime

The date and time that a report job is completed, in Unix format and Coordinated Universal Time (UTC). The value of CompletionTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#creation_timeTime

The date and time that a report job is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.

Returns:

  • (Time)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#report_destinationTypes::ReportDestination

The S3 bucket name and S3 keys for the destination where the report job publishes the report.



8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#report_job_idString

The identifier for a report job. A unique, randomly generated, Unicode, UTF-8 encoded string that is at most 1,024 bytes long. Report job IDs cannot be edited.

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#report_plan_arnString

An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#report_templateString

Identifies the report template for the report. Reports are built using a report template. The report templates are:

RESOURCE_COMPLIANCE_REPORT | CONTROL_COMPLIANCE_REPORT | BACKUP_JOB_REPORT | COPY_JOB_REPORT | RESTORE_JOB_REPORT

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of a report job. The statuses are:

CREATED | RUNNING | COMPLETED | FAILED

COMPLETED means that the report is available for your review at your designated destination. If the status is FAILED, review the StatusMessage for the reason.

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end

#status_messageString

A message explaining the status of the report job.

Returns:

  • (String)


8672
8673
8674
8675
8676
8677
8678
8679
8680
8681
8682
8683
# File 'lib/aws-sdk-backup/types.rb', line 8672

class ReportJob < Struct.new(
  :report_job_id,
  :report_plan_arn,
  :report_template,
  :creation_time,
  :completion_time,
  :status,
  :status_message,
  :report_destination)
  SENSITIVE = []
  include Aws::Structure
end