Class: Aws::Backup::Types::StartCopyJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::StartCopyJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#copy_job_id ⇒ String
Uniquely identifies a copy job.
-
#creation_date ⇒ Time
The date and time that a copy job is created, in Unix format and Coordinated Universal Time (UTC).
-
#is_parent ⇒ Boolean
This is a returned boolean value indicating this is a parent (composite) copy job.
Instance Attribute Details
#copy_job_id ⇒ String
Uniquely identifies a copy job.
8181 8182 8183 8184 8185 8186 8187 |
# File 'lib/aws-sdk-backup/types.rb', line 8181 class StartCopyJobOutput < Struct.new( :copy_job_id, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |
#creation_date ⇒ Time
The date and time that a copy job is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationDate is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
8181 8182 8183 8184 8185 8186 8187 |
# File 'lib/aws-sdk-backup/types.rb', line 8181 class StartCopyJobOutput < Struct.new( :copy_job_id, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |
#is_parent ⇒ Boolean
This is a returned boolean value indicating this is a parent (composite) copy job.
8181 8182 8183 8184 8185 8186 8187 |
# File 'lib/aws-sdk-backup/types.rb', line 8181 class StartCopyJobOutput < Struct.new( :copy_job_id, :creation_date, :is_parent) SENSITIVE = [] include Aws::Structure end |