Class: Aws::Backup::Types::StartScanJobOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::StartScanJobOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_date ⇒ Time
The date and time that a backup job is created, in Unix format and Coordinated Universal Time (UTC).
-
#scan_job_id ⇒ String
Uniquely identifies a request to Backup to back up a resource.
Instance Attribute Details
#creation_date ⇒ Time
The date and time that a backup job is created, in Unix format and Coordinated Universal Time (UTC). The value of ‘CreationDate` is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
10773 10774 10775 10776 10777 10778 |
# File 'lib/aws-sdk-backup/types.rb', line 10773 class StartScanJobOutput < Struct.new( :creation_date, :scan_job_id) SENSITIVE = [] include Aws::Structure end |
#scan_job_id ⇒ String
Uniquely identifies a request to Backup to back up a resource.
10773 10774 10775 10776 10777 10778 |
# File 'lib/aws-sdk-backup/types.rb', line 10773 class StartScanJobOutput < Struct.new( :creation_date, :scan_job_id) SENSITIVE = [] include Aws::Structure end |