Class: Aws::Backup::Types::TieringConfigurationInputForCreate
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::TieringConfigurationInputForCreate
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
This contains metadata about a tiering configuration for create operations.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backup_vault_name ⇒ String
The name of the backup vault where the tiering configuration applies.
-
#resource_selection ⇒ Array<Types::ResourceSelection>
An array of resource selection objects that specify which resources are included in the tiering configuration and their tiering settings.
-
#tiering_configuration_name ⇒ String
The unique name of the tiering configuration.
Instance Attribute Details
#backup_vault_name ⇒ String
The name of the backup vault where the tiering configuration applies. Use ‘*` to apply to all backup vaults.
10893 10894 10895 10896 10897 10898 10899 |
# File 'lib/aws-sdk-backup/types.rb', line 10893 class TieringConfigurationInputForCreate < Struct.new( :tiering_configuration_name, :backup_vault_name, :resource_selection) SENSITIVE = [] include Aws::Structure end |
#resource_selection ⇒ Array<Types::ResourceSelection>
An array of resource selection objects that specify which resources are included in the tiering configuration and their tiering settings.
10893 10894 10895 10896 10897 10898 10899 |
# File 'lib/aws-sdk-backup/types.rb', line 10893 class TieringConfigurationInputForCreate < Struct.new( :tiering_configuration_name, :backup_vault_name, :resource_selection) SENSITIVE = [] include Aws::Structure end |
#tiering_configuration_name ⇒ String
The unique name of the tiering configuration. This cannot be changed after creation, and it must consist of only alphanumeric characters and underscores.
10893 10894 10895 10896 10897 10898 10899 |
# File 'lib/aws-sdk-backup/types.rb', line 10893 class TieringConfigurationInputForCreate < Struct.new( :tiering_configuration_name, :backup_vault_name, :resource_selection) SENSITIVE = [] include Aws::Structure end |