Class: Aws::Backup::Types::UpdateReportPlanOutput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::UpdateReportPlanOutput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#creation_time ⇒ Time
The date and time that a report plan is created, in Unix format and Coordinated Universal Time (UTC).
-
#report_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a resource.
-
#report_plan_name ⇒ String
The unique name of the report plan.
Instance Attribute Details
#creation_time ⇒ Time
The date and time that a report plan is created, in Unix format and Coordinated Universal Time (UTC). The value of CreationTime is accurate to milliseconds. For example, the value 1516925490.087 represents Friday, January 26, 2018 12:11:30.087 AM.
8757 8758 8759 8760 8761 8762 8763 |
# File 'lib/aws-sdk-backup/types.rb', line 8757 class UpdateReportPlanOutput < Struct.new( :report_plan_name, :report_plan_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |
#report_plan_arn ⇒ String
An Amazon Resource Name (ARN) that uniquely identifies a resource. The format of the ARN depends on the resource type.
8757 8758 8759 8760 8761 8762 8763 |
# File 'lib/aws-sdk-backup/types.rb', line 8757 class UpdateReportPlanOutput < Struct.new( :report_plan_name, :report_plan_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |
#report_plan_name ⇒ String
The unique name of the report plan.
8757 8758 8759 8760 8761 8762 8763 |
# File 'lib/aws-sdk-backup/types.rb', line 8757 class UpdateReportPlanOutput < Struct.new( :report_plan_name, :report_plan_arn, :creation_time) SENSITIVE = [] include Aws::Structure end |