Class: Aws::Backup::Types::UpdateRestoreTestingSelectionInput
- Inherits:
-
Struct
- Object
- Struct
- Aws::Backup::Types::UpdateRestoreTestingSelectionInput
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-backup/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#restore_testing_plan_name ⇒ String
The restore testing plan name is required to update the indicated testing plan.
-
#restore_testing_selection ⇒ Types::RestoreTestingSelectionForUpdate
To update your restore testing selection, you can use either protected resource ARNs or conditions, but not both.
-
#restore_testing_selection_name ⇒ String
The required restore testing selection name of the restore testing selection you wish to update.
Instance Attribute Details
#restore_testing_plan_name ⇒ String
The restore testing plan name is required to update the indicated testing plan.
11486 11487 11488 11489 11490 11491 11492 |
# File 'lib/aws-sdk-backup/types.rb', line 11486 class UpdateRestoreTestingSelectionInput < Struct.new( :restore_testing_plan_name, :restore_testing_selection, :restore_testing_selection_name) SENSITIVE = [] include Aws::Structure end |
#restore_testing_selection ⇒ Types::RestoreTestingSelectionForUpdate
To update your restore testing selection, you can use either
protected resource ARNs or conditions, but not both. That is, if
your selection has ProtectedResourceArns, requesting an update
with the parameter ProtectedResourceConditions will be
unsuccessful.
11486 11487 11488 11489 11490 11491 11492 |
# File 'lib/aws-sdk-backup/types.rb', line 11486 class UpdateRestoreTestingSelectionInput < Struct.new( :restore_testing_plan_name, :restore_testing_selection, :restore_testing_selection_name) SENSITIVE = [] include Aws::Structure end |
#restore_testing_selection_name ⇒ String
The required restore testing selection name of the restore testing selection you wish to update.
11486 11487 11488 11489 11490 11491 11492 |
# File 'lib/aws-sdk-backup/types.rb', line 11486 class UpdateRestoreTestingSelectionInput < Struct.new( :restore_testing_plan_name, :restore_testing_selection, :restore_testing_selection_name) SENSITIVE = [] include Aws::Structure end |